@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any
 
 import httpx
 
@@ -22,8 +22,8 @@ def _get_kwargs(
 
 
 def _parse_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[Union[HTTPValidationError, list["CrossSection"]]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> HTTPValidationError | list[CrossSection] | None:
     if response.status_code == 200:
         response_200 = []
         _response_200 = response.json()
@@ -33,10 +33,12 @@ def _parse_response(
             response_200.append(response_200_item)
 
         return response_200
+
     if response.status_code == 422:
         response_422 = HTTPValidationError.from_dict(response.json())
 
         return response_422
+
     if client.raise_on_unexpected_status:
         raise errors.UnexpectedStatus(response.status_code, response.content)
     else:
@@ -44,8 +46,8 @@ def _parse_response(
 
 
 def _build_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Response[Union[HTTPValidationError, list["CrossSection"]]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> Response[HTTPValidationError | list[CrossSection]]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -58,7 +60,7 @@ def sync_detailed(
     project_id: str,
     *,
     client: AuthenticatedClient,
-) -> Response[Union[HTTPValidationError, list["CrossSection"]]]:
+) -> Response[HTTPValidationError | list[CrossSection]]:
     """Get Cross Sections For Project
 
      Get non-deleted cross sections for a project.
@@ -71,7 +73,7 @@ def sync_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, list['CrossSection']]]
+        Response[HTTPValidationError | list[CrossSection]]
     """
 
     kwargs = _get_kwargs(
@@ -89,7 +91,7 @@ def sync(
     project_id: str,
     *,
     client: AuthenticatedClient,
-) -> Optional[Union[HTTPValidationError, list["CrossSection"]]]:
+) -> HTTPValidationError | list[CrossSection] | None:
     """Get Cross Sections For Project
 
      Get non-deleted cross sections for a project.
@@ -102,7 +104,7 @@ def sync(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, list['CrossSection']]
+        HTTPValidationError | list[CrossSection]
     """
 
     return sync_detailed(
@@ -115,7 +117,7 @@ async def asyncio_detailed(
     project_id: str,
     *,
     client: AuthenticatedClient,
-) -> Response[Union[HTTPValidationError, list["CrossSection"]]]:
+) -> Response[HTTPValidationError | list[CrossSection]]:
     """Get Cross Sections For Project
 
      Get non-deleted cross sections for a project.
@@ -128,7 +130,7 @@ async def asyncio_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, list['CrossSection']]]
+        Response[HTTPValidationError | list[CrossSection]]
     """
 
     kwargs = _get_kwargs(
@@ -144,7 +146,7 @@ async def asyncio(
     project_id: str,
     *,
     client: AuthenticatedClient,
-) -> Optional[Union[HTTPValidationError, list["CrossSection"]]]:
+) -> HTTPValidationError | list[CrossSection] | None:
     """Get Cross Sections For Project
 
      Get non-deleted cross sections for a project.
@@ -157,7 +159,7 @@ async def asyncio(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, list['CrossSection']]
+        HTTPValidationError | list[CrossSection]
     """
 
     return (
