@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any
 from uuid import UUID
 
 import httpx
@@ -16,11 +16,11 @@ def _get_kwargs(
     project_id: str,
     location_id: UUID,
     *,
-    file_type: Union[FileType, None, Unset] = UNSET,
+    file_type: FileType | None | Unset = UNSET,
 ) -> dict[str, Any]:
     params: dict[str, Any] = {}
 
-    json_file_type: Union[None, Unset, str]
+    json_file_type: None | str | Unset
     if isinstance(file_type, Unset):
         json_file_type = UNSET
     elif isinstance(file_type, FileType):
@@ -41,8 +41,8 @@ def _get_kwargs(
 
 
 def _parse_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[Union[HTTPValidationError, list["File"]]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> HTTPValidationError | list[File] | None:
     if response.status_code == 200:
         response_200 = []
         _response_200 = response.json()
@@ -52,10 +52,12 @@ def _parse_response(
             response_200.append(response_200_item)
 
         return response_200
+
     if response.status_code == 422:
         response_422 = HTTPValidationError.from_dict(response.json())
 
         return response_422
+
     if client.raise_on_unexpected_status:
         raise errors.UnexpectedStatus(response.status_code, response.content)
     else:
@@ -63,8 +65,8 @@ def _parse_response(
 
 
 def _build_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Response[Union[HTTPValidationError, list["File"]]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> Response[HTTPValidationError | list[File]]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -78,8 +80,8 @@ def sync_detailed(
     location_id: UUID,
     *,
     client: AuthenticatedClient,
-    file_type: Union[FileType, None, Unset] = UNSET,
-) -> Response[Union[HTTPValidationError, list["File"]]]:
+    file_type: FileType | None | Unset = UNSET,
+) -> Response[HTTPValidationError | list[File]]:
     """Get Files In Location In Project
 
      Return database file objects for a specific location and optional file type
@@ -87,14 +89,14 @@ def sync_detailed(
     Args:
         project_id (str):
         location_id (UUID):
-        file_type (Union[FileType, None, Unset]):
+        file_type (FileType | None | Unset):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, list['File']]]
+        Response[HTTPValidationError | list[File]]
     """
 
     kwargs = _get_kwargs(
@@ -115,8 +117,8 @@ def sync(
     location_id: UUID,
     *,
     client: AuthenticatedClient,
-    file_type: Union[FileType, None, Unset] = UNSET,
-) -> Optional[Union[HTTPValidationError, list["File"]]]:
+    file_type: FileType | None | Unset = UNSET,
+) -> HTTPValidationError | list[File] | None:
     """Get Files In Location In Project
 
      Return database file objects for a specific location and optional file type
@@ -124,14 +126,14 @@ def sync(
     Args:
         project_id (str):
         location_id (UUID):
-        file_type (Union[FileType, None, Unset]):
+        file_type (FileType | None | Unset):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, list['File']]
+        HTTPValidationError | list[File]
     """
 
     return sync_detailed(
@@ -147,8 +149,8 @@ async def asyncio_detailed(
     location_id: UUID,
     *,
     client: AuthenticatedClient,
-    file_type: Union[FileType, None, Unset] = UNSET,
-) -> Response[Union[HTTPValidationError, list["File"]]]:
+    file_type: FileType | None | Unset = UNSET,
+) -> Response[HTTPValidationError | list[File]]:
     """Get Files In Location In Project
 
      Return database file objects for a specific location and optional file type
@@ -156,14 +158,14 @@ async def asyncio_detailed(
     Args:
         project_id (str):
         location_id (UUID):
-        file_type (Union[FileType, None, Unset]):
+        file_type (FileType | None | Unset):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, list['File']]]
+        Response[HTTPValidationError | list[File]]
     """
 
     kwargs = _get_kwargs(
@@ -182,8 +184,8 @@ async def asyncio(
     location_id: UUID,
     *,
     client: AuthenticatedClient,
-    file_type: Union[FileType, None, Unset] = UNSET,
-) -> Optional[Union[HTTPValidationError, list["File"]]]:
+    file_type: FileType | None | Unset = UNSET,
+) -> HTTPValidationError | list[File] | None:
     """Get Files In Location In Project
 
      Return database file objects for a specific location and optional file type
@@ -191,14 +193,14 @@ async def asyncio(
     Args:
         project_id (str):
         location_id (UUID):
-        file_type (Union[FileType, None, Unset]):
+        file_type (FileType | None | Unset):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, list['File']]
+        HTTPValidationError | list[File]
     """
 
     return (
