@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any
 from uuid import UUID
 
 import httpx
@@ -52,76 +52,73 @@ def _get_kwargs(
 
 
 def _parse_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-        ],
-    ]
-]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> (
+    HTTPValidationError
+    | MethodAD
+    | MethodCD
+    | MethodCPT
+    | MethodDEF
+    | MethodDP
+    | MethodDT
+    | MethodESA
+    | MethodINC
+    | MethodIW
+    | MethodOTHER
+    | MethodPT
+    | MethodPZ
+    | MethodRCD
+    | MethodRO
+    | MethodRP
+    | MethodRS
+    | MethodRWS
+    | MethodSA
+    | MethodSLB
+    | MethodSPT
+    | MethodSRS
+    | MethodSS
+    | MethodSTI
+    | MethodSVT
+    | MethodTOT
+    | MethodTP
+    | MethodTR
+    | MethodWST
+    | None
+):
     if response.status_code == 200:
 
         def _parse_response_200(
             data: object,
-        ) -> Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-        ]:
+        ) -> (
+            MethodAD
+            | MethodCD
+            | MethodCPT
+            | MethodDEF
+            | MethodDP
+            | MethodDT
+            | MethodESA
+            | MethodINC
+            | MethodIW
+            | MethodOTHER
+            | MethodPT
+            | MethodPZ
+            | MethodRCD
+            | MethodRO
+            | MethodRP
+            | MethodRS
+            | MethodRWS
+            | MethodSA
+            | MethodSLB
+            | MethodSPT
+            | MethodSRS
+            | MethodSS
+            | MethodSTI
+            | MethodSVT
+            | MethodTOT
+            | MethodTP
+            | MethodTR
+            | MethodWST
+        ):
             try:
                 if not isinstance(data, dict):
                     raise TypeError()
@@ -360,41 +357,37 @@ def _parse_response(
 
 
 def _build_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+    *, client: AuthenticatedClient | Client, response: httpx.Response
 ) -> Response[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-        ],
-    ]
+    HTTPValidationError
+    | MethodAD
+    | MethodCD
+    | MethodCPT
+    | MethodDEF
+    | MethodDP
+    | MethodDT
+    | MethodESA
+    | MethodINC
+    | MethodIW
+    | MethodOTHER
+    | MethodPT
+    | MethodPZ
+    | MethodRCD
+    | MethodRO
+    | MethodRP
+    | MethodRS
+    | MethodRWS
+    | MethodSA
+    | MethodSLB
+    | MethodSPT
+    | MethodSRS
+    | MethodSS
+    | MethodSTI
+    | MethodSVT
+    | MethodTOT
+    | MethodTP
+    | MethodTR
+    | MethodWST
 ]:
     return Response(
         status_code=HTTPStatus(response.status_code),
@@ -411,39 +404,35 @@ def sync_detailed(
     *,
     client: AuthenticatedClient,
 ) -> Response[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-        ],
-    ]
+    HTTPValidationError
+    | MethodAD
+    | MethodCD
+    | MethodCPT
+    | MethodDEF
+    | MethodDP
+    | MethodDT
+    | MethodESA
+    | MethodINC
+    | MethodIW
+    | MethodOTHER
+    | MethodPT
+    | MethodPZ
+    | MethodRCD
+    | MethodRO
+    | MethodRP
+    | MethodRS
+    | MethodRWS
+    | MethodSA
+    | MethodSLB
+    | MethodSPT
+    | MethodSRS
+    | MethodSS
+    | MethodSTI
+    | MethodSVT
+    | MethodTOT
+    | MethodTP
+    | MethodTR
+    | MethodWST
 ]:
     """Get Method
 
@@ -459,7 +448,7 @@ def sync_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]]
+        Response[HTTPValidationError | MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC | MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR | MethodWST]
     """
 
     kwargs = _get_kwargs(
@@ -481,41 +470,38 @@ def sync(
     method_id: UUID,
     *,
     client: AuthenticatedClient,
-) -> Optional[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-        ],
-    ]
-]:
+) -> (
+    HTTPValidationError
+    | MethodAD
+    | MethodCD
+    | MethodCPT
+    | MethodDEF
+    | MethodDP
+    | MethodDT
+    | MethodESA
+    | MethodINC
+    | MethodIW
+    | MethodOTHER
+    | MethodPT
+    | MethodPZ
+    | MethodRCD
+    | MethodRO
+    | MethodRP
+    | MethodRS
+    | MethodRWS
+    | MethodSA
+    | MethodSLB
+    | MethodSPT
+    | MethodSRS
+    | MethodSS
+    | MethodSTI
+    | MethodSVT
+    | MethodTOT
+    | MethodTP
+    | MethodTR
+    | MethodWST
+    | None
+):
     """Get Method
 
      Get the method by method_id
@@ -530,7 +516,7 @@ def sync(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]
+        HTTPValidationError | MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC | MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR | MethodWST
     """
 
     return sync_detailed(
@@ -548,39 +534,35 @@ async def asyncio_detailed(
     *,
     client: AuthenticatedClient,
 ) -> Response[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-        ],
-    ]
+    HTTPValidationError
+    | MethodAD
+    | MethodCD
+    | MethodCPT
+    | MethodDEF
+    | MethodDP
+    | MethodDT
+    | MethodESA
+    | MethodINC
+    | MethodIW
+    | MethodOTHER
+    | MethodPT
+    | MethodPZ
+    | MethodRCD
+    | MethodRO
+    | MethodRP
+    | MethodRS
+    | MethodRWS
+    | MethodSA
+    | MethodSLB
+    | MethodSPT
+    | MethodSRS
+    | MethodSS
+    | MethodSTI
+    | MethodSVT
+    | MethodTOT
+    | MethodTP
+    | MethodTR
+    | MethodWST
 ]:
     """Get Method
 
@@ -596,7 +578,7 @@ async def asyncio_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]]
+        Response[HTTPValidationError | MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC | MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR | MethodWST]
     """
 
     kwargs = _get_kwargs(
@@ -616,41 +598,38 @@ async def asyncio(
     method_id: UUID,
     *,
     client: AuthenticatedClient,
-) -> Optional[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-        ],
-    ]
-]:
+) -> (
+    HTTPValidationError
+    | MethodAD
+    | MethodCD
+    | MethodCPT
+    | MethodDEF
+    | MethodDP
+    | MethodDT
+    | MethodESA
+    | MethodINC
+    | MethodIW
+    | MethodOTHER
+    | MethodPT
+    | MethodPZ
+    | MethodRCD
+    | MethodRO
+    | MethodRP
+    | MethodRS
+    | MethodRWS
+    | MethodSA
+    | MethodSLB
+    | MethodSPT
+    | MethodSRS
+    | MethodSS
+    | MethodSTI
+    | MethodSVT
+    | MethodTOT
+    | MethodTP
+    | MethodTR
+    | MethodWST
+    | None
+):
     """Get Method
 
      Get the method by method_id
@@ -665,7 +644,7 @@ async def asyncio(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]
+        HTTPValidationError | MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC | MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR | MethodWST
     """
 
     return (
