@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any
 from uuid import UUID
 
 import httpx
@@ -17,6 +17,7 @@ from ...models.method_srs_data import MethodSRSData
 from ...models.method_ss_data import MethodSSData
 from ...models.method_svt_data import MethodSVTData
 from ...models.method_tot_data import MethodTOTData
+from ...models.method_tr_data import MethodTRData
 from ...models.method_wst_data import MethodWSTData
 from ...types import Response
 
@@ -35,27 +36,25 @@ def _get_kwargs(
 
 
 def _parse_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[
-    Union[
-        HTTPValidationError,
-        list[
-            Union[
-                "MethodCPTData",
-                "MethodDPData",
-                "MethodDTData",
-                "MethodPZData",
-                "MethodRCDData",
-                "MethodRPData",
-                "MethodSRSData",
-                "MethodSSData",
-                "MethodSVTData",
-                "MethodTOTData",
-                "MethodWSTData",
-            ]
-        ],
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> (
+    HTTPValidationError
+    | list[
+        MethodCPTData
+        | MethodDPData
+        | MethodDTData
+        | MethodPZData
+        | MethodRCDData
+        | MethodRPData
+        | MethodSRSData
+        | MethodSSData
+        | MethodSVTData
+        | MethodTOTData
+        | MethodTRData
+        | MethodWSTData
     ]
-]:
+    | None
+):
     if response.status_code == 200:
         response_200 = []
         _response_200 = response.json()
@@ -63,19 +62,20 @@ def _parse_response(
 
             def _parse_response_200_item(
                 data: object,
-            ) -> Union[
-                "MethodCPTData",
-                "MethodDPData",
-                "MethodDTData",
-                "MethodPZData",
-                "MethodRCDData",
-                "MethodRPData",
-                "MethodSRSData",
-                "MethodSSData",
-                "MethodSVTData",
-                "MethodTOTData",
-                "MethodWSTData",
-            ]:
+            ) -> (
+                MethodCPTData
+                | MethodDPData
+                | MethodDTData
+                | MethodPZData
+                | MethodRCDData
+                | MethodRPData
+                | MethodSRSData
+                | MethodSSData
+                | MethodSVTData
+                | MethodTOTData
+                | MethodTRData
+                | MethodWSTData
+            ):
                 try:
                     if not isinstance(data, dict):
                         raise TypeError()
@@ -156,21 +156,31 @@ def _parse_response(
                     return response_200_item_type_9
                 except:  # noqa: E722
                     pass
+                try:
+                    if not isinstance(data, dict):
+                        raise TypeError()
+                    response_200_item_type_10 = MethodTRData.from_dict(data)
+
+                    return response_200_item_type_10
+                except:  # noqa: E722
+                    pass
                 if not isinstance(data, dict):
                     raise TypeError()
-                response_200_item_type_10 = MethodWSTData.from_dict(data)
+                response_200_item_type_11 = MethodWSTData.from_dict(data)
 
-                return response_200_item_type_10
+                return response_200_item_type_11
 
             response_200_item = _parse_response_200_item(response_200_item_data)
 
             response_200.append(response_200_item)
 
         return response_200
+
     if response.status_code == 422:
         response_422 = HTTPValidationError.from_dict(response.json())
 
         return response_422
+
     if client.raise_on_unexpected_status:
         raise errors.UnexpectedStatus(response.status_code, response.content)
     else:
@@ -178,25 +188,22 @@ def _parse_response(
 
 
 def _build_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+    *, client: AuthenticatedClient | Client, response: httpx.Response
 ) -> Response[
-    Union[
-        HTTPValidationError,
-        list[
-            Union[
-                "MethodCPTData",
-                "MethodDPData",
-                "MethodDTData",
-                "MethodPZData",
-                "MethodRCDData",
-                "MethodRPData",
-                "MethodSRSData",
-                "MethodSSData",
-                "MethodSVTData",
-                "MethodTOTData",
-                "MethodWSTData",
-            ]
-        ],
+    HTTPValidationError
+    | list[
+        MethodCPTData
+        | MethodDPData
+        | MethodDTData
+        | MethodPZData
+        | MethodRCDData
+        | MethodRPData
+        | MethodSRSData
+        | MethodSSData
+        | MethodSVTData
+        | MethodTOTData
+        | MethodTRData
+        | MethodWSTData
     ]
 ]:
     return Response(
@@ -214,23 +221,20 @@ def sync_detailed(
     *,
     client: AuthenticatedClient,
 ) -> Response[
-    Union[
-        HTTPValidationError,
-        list[
-            Union[
-                "MethodCPTData",
-                "MethodDPData",
-                "MethodDTData",
-                "MethodPZData",
-                "MethodRCDData",
-                "MethodRPData",
-                "MethodSRSData",
-                "MethodSSData",
-                "MethodSVTData",
-                "MethodTOTData",
-                "MethodWSTData",
-            ]
-        ],
+    HTTPValidationError
+    | list[
+        MethodCPTData
+        | MethodDPData
+        | MethodDTData
+        | MethodPZData
+        | MethodRCDData
+        | MethodRPData
+        | MethodSRSData
+        | MethodSSData
+        | MethodSVTData
+        | MethodTOTData
+        | MethodTRData
+        | MethodWSTData
     ]
 ]:
     """Get Methods Data
@@ -247,7 +251,7 @@ def sync_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, list[Union['MethodCPTData', 'MethodDPData', 'MethodDTData', 'MethodPZData', 'MethodRCDData', 'MethodRPData', 'MethodSRSData', 'MethodSSData', 'MethodSVTData', 'MethodTOTData', 'MethodWSTData']]]]
+        Response[HTTPValidationError | list[MethodCPTData | MethodDPData | MethodDTData | MethodPZData | MethodRCDData | MethodRPData | MethodSRSData | MethodSSData | MethodSVTData | MethodTOTData | MethodTRData | MethodWSTData]]
     """
 
     kwargs = _get_kwargs(
@@ -269,26 +273,24 @@ def sync(
     method_id: UUID,
     *,
     client: AuthenticatedClient,
-) -> Optional[
-    Union[
-        HTTPValidationError,
-        list[
-            Union[
-                "MethodCPTData",
-                "MethodDPData",
-                "MethodDTData",
-                "MethodPZData",
-                "MethodRCDData",
-                "MethodRPData",
-                "MethodSRSData",
-                "MethodSSData",
-                "MethodSVTData",
-                "MethodTOTData",
-                "MethodWSTData",
-            ]
-        ],
+) -> (
+    HTTPValidationError
+    | list[
+        MethodCPTData
+        | MethodDPData
+        | MethodDTData
+        | MethodPZData
+        | MethodRCDData
+        | MethodRPData
+        | MethodSRSData
+        | MethodSSData
+        | MethodSVTData
+        | MethodTOTData
+        | MethodTRData
+        | MethodWSTData
     ]
-]:
+    | None
+):
     """Get Methods Data
 
      Get the method's data
@@ -303,7 +305,7 @@ def sync(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, list[Union['MethodCPTData', 'MethodDPData', 'MethodDTData', 'MethodPZData', 'MethodRCDData', 'MethodRPData', 'MethodSRSData', 'MethodSSData', 'MethodSVTData', 'MethodTOTData', 'MethodWSTData']]]
+        HTTPValidationError | list[MethodCPTData | MethodDPData | MethodDTData | MethodPZData | MethodRCDData | MethodRPData | MethodSRSData | MethodSSData | MethodSVTData | MethodTOTData | MethodTRData | MethodWSTData]
     """
 
     return sync_detailed(
@@ -321,23 +323,20 @@ async def asyncio_detailed(
     *,
     client: AuthenticatedClient,
 ) -> Response[
-    Union[
-        HTTPValidationError,
-        list[
-            Union[
-                "MethodCPTData",
-                "MethodDPData",
-                "MethodDTData",
-                "MethodPZData",
-                "MethodRCDData",
-                "MethodRPData",
-                "MethodSRSData",
-                "MethodSSData",
-                "MethodSVTData",
-                "MethodTOTData",
-                "MethodWSTData",
-            ]
-        ],
+    HTTPValidationError
+    | list[
+        MethodCPTData
+        | MethodDPData
+        | MethodDTData
+        | MethodPZData
+        | MethodRCDData
+        | MethodRPData
+        | MethodSRSData
+        | MethodSSData
+        | MethodSVTData
+        | MethodTOTData
+        | MethodTRData
+        | MethodWSTData
     ]
 ]:
     """Get Methods Data
@@ -354,7 +353,7 @@ async def asyncio_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, list[Union['MethodCPTData', 'MethodDPData', 'MethodDTData', 'MethodPZData', 'MethodRCDData', 'MethodRPData', 'MethodSRSData', 'MethodSSData', 'MethodSVTData', 'MethodTOTData', 'MethodWSTData']]]]
+        Response[HTTPValidationError | list[MethodCPTData | MethodDPData | MethodDTData | MethodPZData | MethodRCDData | MethodRPData | MethodSRSData | MethodSSData | MethodSVTData | MethodTOTData | MethodTRData | MethodWSTData]]
     """
 
     kwargs = _get_kwargs(
@@ -374,26 +373,24 @@ async def asyncio(
     method_id: UUID,
     *,
     client: AuthenticatedClient,
-) -> Optional[
-    Union[
-        HTTPValidationError,
-        list[
-            Union[
-                "MethodCPTData",
-                "MethodDPData",
-                "MethodDTData",
-                "MethodPZData",
-                "MethodRCDData",
-                "MethodRPData",
-                "MethodSRSData",
-                "MethodSSData",
-                "MethodSVTData",
-                "MethodTOTData",
-                "MethodWSTData",
-            ]
-        ],
+) -> (
+    HTTPValidationError
+    | list[
+        MethodCPTData
+        | MethodDPData
+        | MethodDTData
+        | MethodPZData
+        | MethodRCDData
+        | MethodRPData
+        | MethodSRSData
+        | MethodSSData
+        | MethodSVTData
+        | MethodTOTData
+        | MethodTRData
+        | MethodWSTData
     ]
-]:
+    | None
+):
     """Get Methods Data
 
      Get the method's data
@@ -408,7 +405,7 @@ async def asyncio(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, list[Union['MethodCPTData', 'MethodDPData', 'MethodDTData', 'MethodPZData', 'MethodRCDData', 'MethodRPData', 'MethodSRSData', 'MethodSSData', 'MethodSVTData', 'MethodTOTData', 'MethodWSTData']]]
+        HTTPValidationError | list[MethodCPTData | MethodDPData | MethodDTData | MethodPZData | MethodRCDData | MethodRPData | MethodSRSData | MethodSSData | MethodSVTData | MethodTOTData | MethodTRData | MethodWSTData]
     """
 
     return (
