@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any
 from uuid import UUID
 
 import httpx
@@ -44,8 +44,8 @@ def _get_kwargs(
     location_id: UUID,
     method_type_name: MethodTypeEnumStr,
     *,
-    skip: Union[Unset, int] = 0,
-    limit: Union[Unset, int] = 100,
+    skip: int | Unset = 0,
+    limit: int | Unset = 100,
 ) -> dict[str, Any]:
     params: dict[str, Any] = {}
 
@@ -65,44 +65,41 @@ def _get_kwargs(
 
 
 def _parse_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[
-    Union[
-        HTTPValidationError,
-        list[
-            Union[
-                "MethodAD",
-                "MethodCD",
-                "MethodCPT",
-                "MethodDEF",
-                "MethodDP",
-                "MethodDT",
-                "MethodESA",
-                "MethodINC",
-                "MethodIW",
-                "MethodOTHER",
-                "MethodPT",
-                "MethodPZ",
-                "MethodRCD",
-                "MethodRO",
-                "MethodRP",
-                "MethodRS",
-                "MethodRWS",
-                "MethodSA",
-                "MethodSLB",
-                "MethodSPT",
-                "MethodSRS",
-                "MethodSS",
-                "MethodSTI",
-                "MethodSVT",
-                "MethodTOT",
-                "MethodTP",
-                "MethodTR",
-                "MethodWST",
-            ]
-        ],
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> (
+    HTTPValidationError
+    | list[
+        MethodAD
+        | MethodCD
+        | MethodCPT
+        | MethodDEF
+        | MethodDP
+        | MethodDT
+        | MethodESA
+        | MethodINC
+        | MethodIW
+        | MethodOTHER
+        | MethodPT
+        | MethodPZ
+        | MethodRCD
+        | MethodRO
+        | MethodRP
+        | MethodRS
+        | MethodRWS
+        | MethodSA
+        | MethodSLB
+        | MethodSPT
+        | MethodSRS
+        | MethodSS
+        | MethodSTI
+        | MethodSVT
+        | MethodTOT
+        | MethodTP
+        | MethodTR
+        | MethodWST
     ]
-]:
+    | None
+):
     if response.status_code == 200:
         response_200 = []
         _response_200 = response.json()
@@ -110,36 +107,36 @@ def _parse_response(
 
             def _parse_response_200_item(
                 data: object,
-            ) -> Union[
-                "MethodAD",
-                "MethodCD",
-                "MethodCPT",
-                "MethodDEF",
-                "MethodDP",
-                "MethodDT",
-                "MethodESA",
-                "MethodINC",
-                "MethodIW",
-                "MethodOTHER",
-                "MethodPT",
-                "MethodPZ",
-                "MethodRCD",
-                "MethodRO",
-                "MethodRP",
-                "MethodRS",
-                "MethodRWS",
-                "MethodSA",
-                "MethodSLB",
-                "MethodSPT",
-                "MethodSRS",
-                "MethodSS",
-                "MethodSTI",
-                "MethodSVT",
-                "MethodTOT",
-                "MethodTP",
-                "MethodTR",
-                "MethodWST",
-            ]:
+            ) -> (
+                MethodAD
+                | MethodCD
+                | MethodCPT
+                | MethodDEF
+                | MethodDP
+                | MethodDT
+                | MethodESA
+                | MethodINC
+                | MethodIW
+                | MethodOTHER
+                | MethodPT
+                | MethodPZ
+                | MethodRCD
+                | MethodRO
+                | MethodRP
+                | MethodRS
+                | MethodRWS
+                | MethodSA
+                | MethodSLB
+                | MethodSPT
+                | MethodSRS
+                | MethodSS
+                | MethodSTI
+                | MethodSVT
+                | MethodTOT
+                | MethodTP
+                | MethodTR
+                | MethodWST
+            ):
                 try:
                     if not isinstance(data, dict):
                         raise TypeError()
@@ -380,42 +377,38 @@ def _parse_response(
 
 
 def _build_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+    *, client: AuthenticatedClient | Client, response: httpx.Response
 ) -> Response[
-    Union[
-        HTTPValidationError,
-        list[
-            Union[
-                "MethodAD",
-                "MethodCD",
-                "MethodCPT",
-                "MethodDEF",
-                "MethodDP",
-                "MethodDT",
-                "MethodESA",
-                "MethodINC",
-                "MethodIW",
-                "MethodOTHER",
-                "MethodPT",
-                "MethodPZ",
-                "MethodRCD",
-                "MethodRO",
-                "MethodRP",
-                "MethodRS",
-                "MethodRWS",
-                "MethodSA",
-                "MethodSLB",
-                "MethodSPT",
-                "MethodSRS",
-                "MethodSS",
-                "MethodSTI",
-                "MethodSVT",
-                "MethodTOT",
-                "MethodTP",
-                "MethodTR",
-                "MethodWST",
-            ]
-        ],
+    HTTPValidationError
+    | list[
+        MethodAD
+        | MethodCD
+        | MethodCPT
+        | MethodDEF
+        | MethodDP
+        | MethodDT
+        | MethodESA
+        | MethodINC
+        | MethodIW
+        | MethodOTHER
+        | MethodPT
+        | MethodPZ
+        | MethodRCD
+        | MethodRO
+        | MethodRP
+        | MethodRS
+        | MethodRWS
+        | MethodSA
+        | MethodSLB
+        | MethodSPT
+        | MethodSRS
+        | MethodSS
+        | MethodSTI
+        | MethodSVT
+        | MethodTOT
+        | MethodTP
+        | MethodTR
+        | MethodWST
     ]
 ]:
     return Response(
@@ -432,43 +425,39 @@ def sync_detailed(
     method_type_name: MethodTypeEnumStr,
     *,
     client: AuthenticatedClient,
-    skip: Union[Unset, int] = 0,
-    limit: Union[Unset, int] = 100,
+    skip: int | Unset = 0,
+    limit: int | Unset = 100,
 ) -> Response[
-    Union[
-        HTTPValidationError,
-        list[
-            Union[
-                "MethodAD",
-                "MethodCD",
-                "MethodCPT",
-                "MethodDEF",
-                "MethodDP",
-                "MethodDT",
-                "MethodESA",
-                "MethodINC",
-                "MethodIW",
-                "MethodOTHER",
-                "MethodPT",
-                "MethodPZ",
-                "MethodRCD",
-                "MethodRO",
-                "MethodRP",
-                "MethodRS",
-                "MethodRWS",
-                "MethodSA",
-                "MethodSLB",
-                "MethodSPT",
-                "MethodSRS",
-                "MethodSS",
-                "MethodSTI",
-                "MethodSVT",
-                "MethodTOT",
-                "MethodTP",
-                "MethodTR",
-                "MethodWST",
-            ]
-        ],
+    HTTPValidationError
+    | list[
+        MethodAD
+        | MethodCD
+        | MethodCPT
+        | MethodDEF
+        | MethodDP
+        | MethodDT
+        | MethodESA
+        | MethodINC
+        | MethodIW
+        | MethodOTHER
+        | MethodPT
+        | MethodPZ
+        | MethodRCD
+        | MethodRO
+        | MethodRP
+        | MethodRS
+        | MethodRWS
+        | MethodSA
+        | MethodSLB
+        | MethodSPT
+        | MethodSRS
+        | MethodSS
+        | MethodSTI
+        | MethodSVT
+        | MethodTOT
+        | MethodTP
+        | MethodTR
+        | MethodWST
     ]
 ]:
     """Get Methods For Location Of Type
@@ -479,15 +468,15 @@ def sync_detailed(
         project_id (str):
         location_id (UUID):
         method_type_name (MethodTypeEnumStr):
-        skip (Union[Unset, int]):  Default: 0.
-        limit (Union[Unset, int]):  Default: 100.
+        skip (int | Unset):  Default: 0.
+        limit (int | Unset):  Default: 100.
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, list[Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]]]
+        Response[HTTPValidationError | list[MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC | MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR | MethodWST]]
     """
 
     kwargs = _get_kwargs(
@@ -511,45 +500,42 @@ def sync(
     method_type_name: MethodTypeEnumStr,
     *,
     client: AuthenticatedClient,
-    skip: Union[Unset, int] = 0,
-    limit: Union[Unset, int] = 100,
-) -> Optional[
-    Union[
-        HTTPValidationError,
-        list[
-            Union[
-                "MethodAD",
-                "MethodCD",
-                "MethodCPT",
-                "MethodDEF",
-                "MethodDP",
-                "MethodDT",
-                "MethodESA",
-                "MethodINC",
-                "MethodIW",
-                "MethodOTHER",
-                "MethodPT",
-                "MethodPZ",
-                "MethodRCD",
-                "MethodRO",
-                "MethodRP",
-                "MethodRS",
-                "MethodRWS",
-                "MethodSA",
-                "MethodSLB",
-                "MethodSPT",
-                "MethodSRS",
-                "MethodSS",
-                "MethodSTI",
-                "MethodSVT",
-                "MethodTOT",
-                "MethodTP",
-                "MethodTR",
-                "MethodWST",
-            ]
-        ],
+    skip: int | Unset = 0,
+    limit: int | Unset = 100,
+) -> (
+    HTTPValidationError
+    | list[
+        MethodAD
+        | MethodCD
+        | MethodCPT
+        | MethodDEF
+        | MethodDP
+        | MethodDT
+        | MethodESA
+        | MethodINC
+        | MethodIW
+        | MethodOTHER
+        | MethodPT
+        | MethodPZ
+        | MethodRCD
+        | MethodRO
+        | MethodRP
+        | MethodRS
+        | MethodRWS
+        | MethodSA
+        | MethodSLB
+        | MethodSPT
+        | MethodSRS
+        | MethodSS
+        | MethodSTI
+        | MethodSVT
+        | MethodTOT
+        | MethodTP
+        | MethodTR
+        | MethodWST
     ]
-]:
+    | None
+):
     """Get Methods For Location Of Type
 
      Get all methods of type `method_type_name` from location.
@@ -558,15 +544,15 @@ def sync(
         project_id (str):
         location_id (UUID):
         method_type_name (MethodTypeEnumStr):
-        skip (Union[Unset, int]):  Default: 0.
-        limit (Union[Unset, int]):  Default: 100.
+        skip (int | Unset):  Default: 0.
+        limit (int | Unset):  Default: 100.
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, list[Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]]
+        HTTPValidationError | list[MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC | MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR | MethodWST]
     """
 
     return sync_detailed(
@@ -585,43 +571,39 @@ async def asyncio_detailed(
     method_type_name: MethodTypeEnumStr,
     *,
     client: AuthenticatedClient,
-    skip: Union[Unset, int] = 0,
-    limit: Union[Unset, int] = 100,
+    skip: int | Unset = 0,
+    limit: int | Unset = 100,
 ) -> Response[
-    Union[
-        HTTPValidationError,
-        list[
-            Union[
-                "MethodAD",
-                "MethodCD",
-                "MethodCPT",
-                "MethodDEF",
-                "MethodDP",
-                "MethodDT",
-                "MethodESA",
-                "MethodINC",
-                "MethodIW",
-                "MethodOTHER",
-                "MethodPT",
-                "MethodPZ",
-                "MethodRCD",
-                "MethodRO",
-                "MethodRP",
-                "MethodRS",
-                "MethodRWS",
-                "MethodSA",
-                "MethodSLB",
-                "MethodSPT",
-                "MethodSRS",
-                "MethodSS",
-                "MethodSTI",
-                "MethodSVT",
-                "MethodTOT",
-                "MethodTP",
-                "MethodTR",
-                "MethodWST",
-            ]
-        ],
+    HTTPValidationError
+    | list[
+        MethodAD
+        | MethodCD
+        | MethodCPT
+        | MethodDEF
+        | MethodDP
+        | MethodDT
+        | MethodESA
+        | MethodINC
+        | MethodIW
+        | MethodOTHER
+        | MethodPT
+        | MethodPZ
+        | MethodRCD
+        | MethodRO
+        | MethodRP
+        | MethodRS
+        | MethodRWS
+        | MethodSA
+        | MethodSLB
+        | MethodSPT
+        | MethodSRS
+        | MethodSS
+        | MethodSTI
+        | MethodSVT
+        | MethodTOT
+        | MethodTP
+        | MethodTR
+        | MethodWST
     ]
 ]:
     """Get Methods For Location Of Type
@@ -632,15 +614,15 @@ async def asyncio_detailed(
         project_id (str):
         location_id (UUID):
         method_type_name (MethodTypeEnumStr):
-        skip (Union[Unset, int]):  Default: 0.
-        limit (Union[Unset, int]):  Default: 100.
+        skip (int | Unset):  Default: 0.
+        limit (int | Unset):  Default: 100.
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, list[Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]]]
+        Response[HTTPValidationError | list[MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC | MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR | MethodWST]]
     """
 
     kwargs = _get_kwargs(
@@ -662,45 +644,42 @@ async def asyncio(
     method_type_name: MethodTypeEnumStr,
     *,
     client: AuthenticatedClient,
-    skip: Union[Unset, int] = 0,
-    limit: Union[Unset, int] = 100,
-) -> Optional[
-    Union[
-        HTTPValidationError,
-        list[
-            Union[
-                "MethodAD",
-                "MethodCD",
-                "MethodCPT",
-                "MethodDEF",
-                "MethodDP",
-                "MethodDT",
-                "MethodESA",
-                "MethodINC",
-                "MethodIW",
-                "MethodOTHER",
-                "MethodPT",
-                "MethodPZ",
-                "MethodRCD",
-                "MethodRO",
-                "MethodRP",
-                "MethodRS",
-                "MethodRWS",
-                "MethodSA",
-                "MethodSLB",
-                "MethodSPT",
-                "MethodSRS",
-                "MethodSS",
-                "MethodSTI",
-                "MethodSVT",
-                "MethodTOT",
-                "MethodTP",
-                "MethodTR",
-                "MethodWST",
-            ]
-        ],
+    skip: int | Unset = 0,
+    limit: int | Unset = 100,
+) -> (
+    HTTPValidationError
+    | list[
+        MethodAD
+        | MethodCD
+        | MethodCPT
+        | MethodDEF
+        | MethodDP
+        | MethodDT
+        | MethodESA
+        | MethodINC
+        | MethodIW
+        | MethodOTHER
+        | MethodPT
+        | MethodPZ
+        | MethodRCD
+        | MethodRO
+        | MethodRP
+        | MethodRS
+        | MethodRWS
+        | MethodSA
+        | MethodSLB
+        | MethodSPT
+        | MethodSRS
+        | MethodSS
+        | MethodSTI
+        | MethodSVT
+        | MethodTOT
+        | MethodTP
+        | MethodTR
+        | MethodWST
     ]
-]:
+    | None
+):
     """Get Methods For Location Of Type
 
      Get all methods of type `method_type_name` from location.
@@ -709,15 +688,15 @@ async def asyncio(
         project_id (str):
         location_id (UUID):
         method_type_name (MethodTypeEnumStr):
-        skip (Union[Unset, int]):  Default: 0.
-        limit (Union[Unset, int]):  Default: 100.
+        skip (int | Unset):  Default: 0.
+        limit (int | Unset):  Default: 100.
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, list[Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]]
+        HTTPValidationError | list[MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC | MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR | MethodWST]
     """
 
     return (
