@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any
 from uuid import UUID
 
 import httpx
@@ -71,36 +71,34 @@ def _get_kwargs(
     location_id: UUID,
     method_id: UUID,
     *,
-    body: Union[
-        "MethodADUpdate",
-        "MethodCDUpdate",
-        "MethodCPTUpdate",
-        "MethodDEFUpdate",
-        "MethodDPUpdate",
-        "MethodDTUpdate",
-        "MethodESAUpdate",
-        "MethodINCUpdate",
-        "MethodIWUpdate",
-        "MethodOTHERUpdate",
-        "MethodPTUpdate",
-        "MethodPZUpdate",
-        "MethodRCDUpdate",
-        "MethodROUpdate",
-        "MethodRPUpdate",
-        "MethodRSUpdate",
-        "MethodRWSUpdate",
-        "MethodSAUpdate",
-        "MethodSLBUpdate",
-        "MethodSPTUpdate",
-        "MethodSRSUpdate",
-        "MethodSSUpdate",
-        "MethodSTIUpdate",
-        "MethodSVTUpdate",
-        "MethodTOTUpdate",
-        "MethodTPUpdate",
-        "MethodTRUpdate",
-        "MethodWSTUpdate",
-    ],
+    body: MethodADUpdate
+    | MethodCDUpdate
+    | MethodCPTUpdate
+    | MethodDEFUpdate
+    | MethodDPUpdate
+    | MethodDTUpdate
+    | MethodESAUpdate
+    | MethodINCUpdate
+    | MethodIWUpdate
+    | MethodOTHERUpdate
+    | MethodPTUpdate
+    | MethodPZUpdate
+    | MethodRCDUpdate
+    | MethodROUpdate
+    | MethodRPUpdate
+    | MethodRSUpdate
+    | MethodRWSUpdate
+    | MethodSAUpdate
+    | MethodSLBUpdate
+    | MethodSPTUpdate
+    | MethodSRSUpdate
+    | MethodSSUpdate
+    | MethodSTIUpdate
+    | MethodSVTUpdate
+    | MethodTOTUpdate
+    | MethodTPUpdate
+    | MethodTRUpdate
+    | MethodWSTUpdate,
 ) -> dict[str, Any]:
     headers: dict[str, Any] = {}
 
@@ -174,76 +172,73 @@ def _get_kwargs(
 
 
 def _parse_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-        ],
-    ]
-]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> (
+    HTTPValidationError
+    | MethodAD
+    | MethodCD
+    | MethodCPT
+    | MethodDEF
+    | MethodDP
+    | MethodDT
+    | MethodESA
+    | MethodINC
+    | MethodIW
+    | MethodOTHER
+    | MethodPT
+    | MethodPZ
+    | MethodRCD
+    | MethodRO
+    | MethodRP
+    | MethodRS
+    | MethodRWS
+    | MethodSA
+    | MethodSLB
+    | MethodSPT
+    | MethodSRS
+    | MethodSS
+    | MethodSTI
+    | MethodSVT
+    | MethodTOT
+    | MethodTP
+    | MethodTR
+    | MethodWST
+    | None
+):
     if response.status_code == 200:
 
         def _parse_response_200(
             data: object,
-        ) -> Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-        ]:
+        ) -> (
+            MethodAD
+            | MethodCD
+            | MethodCPT
+            | MethodDEF
+            | MethodDP
+            | MethodDT
+            | MethodESA
+            | MethodINC
+            | MethodIW
+            | MethodOTHER
+            | MethodPT
+            | MethodPZ
+            | MethodRCD
+            | MethodRO
+            | MethodRP
+            | MethodRS
+            | MethodRWS
+            | MethodSA
+            | MethodSLB
+            | MethodSPT
+            | MethodSRS
+            | MethodSS
+            | MethodSTI
+            | MethodSVT
+            | MethodTOT
+            | MethodTP
+            | MethodTR
+            | MethodWST
+        ):
             try:
                 if not isinstance(data, dict):
                     raise TypeError()
@@ -482,41 +477,37 @@ def _parse_response(
 
 
 def _build_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+    *, client: AuthenticatedClient | Client, response: httpx.Response
 ) -> Response[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-        ],
-    ]
+    HTTPValidationError
+    | MethodAD
+    | MethodCD
+    | MethodCPT
+    | MethodDEF
+    | MethodDP
+    | MethodDT
+    | MethodESA
+    | MethodINC
+    | MethodIW
+    | MethodOTHER
+    | MethodPT
+    | MethodPZ
+    | MethodRCD
+    | MethodRO
+    | MethodRP
+    | MethodRS
+    | MethodRWS
+    | MethodSA
+    | MethodSLB
+    | MethodSPT
+    | MethodSRS
+    | MethodSS
+    | MethodSTI
+    | MethodSVT
+    | MethodTOT
+    | MethodTP
+    | MethodTR
+    | MethodWST
 ]:
     return Response(
         status_code=HTTPStatus(response.status_code),
@@ -532,70 +523,64 @@ def sync_detailed(
     method_id: UUID,
     *,
     client: AuthenticatedClient,
-    body: Union[
-        "MethodADUpdate",
-        "MethodCDUpdate",
-        "MethodCPTUpdate",
-        "MethodDEFUpdate",
-        "MethodDPUpdate",
-        "MethodDTUpdate",
-        "MethodESAUpdate",
-        "MethodINCUpdate",
-        "MethodIWUpdate",
-        "MethodOTHERUpdate",
-        "MethodPTUpdate",
-        "MethodPZUpdate",
-        "MethodRCDUpdate",
-        "MethodROUpdate",
-        "MethodRPUpdate",
-        "MethodRSUpdate",
-        "MethodRWSUpdate",
-        "MethodSAUpdate",
-        "MethodSLBUpdate",
-        "MethodSPTUpdate",
-        "MethodSRSUpdate",
-        "MethodSSUpdate",
-        "MethodSTIUpdate",
-        "MethodSVTUpdate",
-        "MethodTOTUpdate",
-        "MethodTPUpdate",
-        "MethodTRUpdate",
-        "MethodWSTUpdate",
-    ],
+    body: MethodADUpdate
+    | MethodCDUpdate
+    | MethodCPTUpdate
+    | MethodDEFUpdate
+    | MethodDPUpdate
+    | MethodDTUpdate
+    | MethodESAUpdate
+    | MethodINCUpdate
+    | MethodIWUpdate
+    | MethodOTHERUpdate
+    | MethodPTUpdate
+    | MethodPZUpdate
+    | MethodRCDUpdate
+    | MethodROUpdate
+    | MethodRPUpdate
+    | MethodRSUpdate
+    | MethodRWSUpdate
+    | MethodSAUpdate
+    | MethodSLBUpdate
+    | MethodSPTUpdate
+    | MethodSRSUpdate
+    | MethodSSUpdate
+    | MethodSTIUpdate
+    | MethodSVTUpdate
+    | MethodTOTUpdate
+    | MethodTPUpdate
+    | MethodTRUpdate
+    | MethodWSTUpdate,
 ) -> Response[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-        ],
-    ]
+    HTTPValidationError
+    | MethodAD
+    | MethodCD
+    | MethodCPT
+    | MethodDEF
+    | MethodDP
+    | MethodDT
+    | MethodESA
+    | MethodINC
+    | MethodIW
+    | MethodOTHER
+    | MethodPT
+    | MethodPZ
+    | MethodRCD
+    | MethodRO
+    | MethodRP
+    | MethodRS
+    | MethodRWS
+    | MethodSA
+    | MethodSLB
+    | MethodSPT
+    | MethodSRS
+    | MethodSS
+    | MethodSTI
+    | MethodSVT
+    | MethodTOT
+    | MethodTP
+    | MethodTR
+    | MethodWST
 ]:
     """Update Method For Location
 
@@ -605,20 +590,19 @@ def sync_detailed(
         project_id (str):
         location_id (UUID):
         method_id (UUID):
-        body (Union['MethodADUpdate', 'MethodCDUpdate', 'MethodCPTUpdate', 'MethodDEFUpdate',
-            'MethodDPUpdate', 'MethodDTUpdate', 'MethodESAUpdate', 'MethodINCUpdate',
-            'MethodIWUpdate', 'MethodOTHERUpdate', 'MethodPTUpdate', 'MethodPZUpdate',
-            'MethodRCDUpdate', 'MethodROUpdate', 'MethodRPUpdate', 'MethodRSUpdate',
-            'MethodRWSUpdate', 'MethodSAUpdate', 'MethodSLBUpdate', 'MethodSPTUpdate',
-            'MethodSRSUpdate', 'MethodSSUpdate', 'MethodSTIUpdate', 'MethodSVTUpdate',
-            'MethodTOTUpdate', 'MethodTPUpdate', 'MethodTRUpdate', 'MethodWSTUpdate']):
+        body (MethodADUpdate | MethodCDUpdate | MethodCPTUpdate | MethodDEFUpdate | MethodDPUpdate
+            | MethodDTUpdate | MethodESAUpdate | MethodINCUpdate | MethodIWUpdate | MethodOTHERUpdate
+            | MethodPTUpdate | MethodPZUpdate | MethodRCDUpdate | MethodROUpdate | MethodRPUpdate |
+            MethodRSUpdate | MethodRWSUpdate | MethodSAUpdate | MethodSLBUpdate | MethodSPTUpdate |
+            MethodSRSUpdate | MethodSSUpdate | MethodSTIUpdate | MethodSVTUpdate | MethodTOTUpdate |
+            MethodTPUpdate | MethodTRUpdate | MethodWSTUpdate):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]]
+        Response[HTTPValidationError | MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC | MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR | MethodWST]
     """
 
     kwargs = _get_kwargs(
@@ -641,71 +625,66 @@ def sync(
     method_id: UUID,
     *,
     client: AuthenticatedClient,
-    body: Union[
-        "MethodADUpdate",
-        "MethodCDUpdate",
-        "MethodCPTUpdate",
-        "MethodDEFUpdate",
-        "MethodDPUpdate",
-        "MethodDTUpdate",
-        "MethodESAUpdate",
-        "MethodINCUpdate",
-        "MethodIWUpdate",
-        "MethodOTHERUpdate",
-        "MethodPTUpdate",
-        "MethodPZUpdate",
-        "MethodRCDUpdate",
-        "MethodROUpdate",
-        "MethodRPUpdate",
-        "MethodRSUpdate",
-        "MethodRWSUpdate",
-        "MethodSAUpdate",
-        "MethodSLBUpdate",
-        "MethodSPTUpdate",
-        "MethodSRSUpdate",
-        "MethodSSUpdate",
-        "MethodSTIUpdate",
-        "MethodSVTUpdate",
-        "MethodTOTUpdate",
-        "MethodTPUpdate",
-        "MethodTRUpdate",
-        "MethodWSTUpdate",
-    ],
-) -> Optional[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-        ],
-    ]
-]:
+    body: MethodADUpdate
+    | MethodCDUpdate
+    | MethodCPTUpdate
+    | MethodDEFUpdate
+    | MethodDPUpdate
+    | MethodDTUpdate
+    | MethodESAUpdate
+    | MethodINCUpdate
+    | MethodIWUpdate
+    | MethodOTHERUpdate
+    | MethodPTUpdate
+    | MethodPZUpdate
+    | MethodRCDUpdate
+    | MethodROUpdate
+    | MethodRPUpdate
+    | MethodRSUpdate
+    | MethodRWSUpdate
+    | MethodSAUpdate
+    | MethodSLBUpdate
+    | MethodSPTUpdate
+    | MethodSRSUpdate
+    | MethodSSUpdate
+    | MethodSTIUpdate
+    | MethodSVTUpdate
+    | MethodTOTUpdate
+    | MethodTPUpdate
+    | MethodTRUpdate
+    | MethodWSTUpdate,
+) -> (
+    HTTPValidationError
+    | MethodAD
+    | MethodCD
+    | MethodCPT
+    | MethodDEF
+    | MethodDP
+    | MethodDT
+    | MethodESA
+    | MethodINC
+    | MethodIW
+    | MethodOTHER
+    | MethodPT
+    | MethodPZ
+    | MethodRCD
+    | MethodRO
+    | MethodRP
+    | MethodRS
+    | MethodRWS
+    | MethodSA
+    | MethodSLB
+    | MethodSPT
+    | MethodSRS
+    | MethodSS
+    | MethodSTI
+    | MethodSVT
+    | MethodTOT
+    | MethodTP
+    | MethodTR
+    | MethodWST
+    | None
+):
     """Update Method For Location
 
      Update method
@@ -714,20 +693,19 @@ def sync(
         project_id (str):
         location_id (UUID):
         method_id (UUID):
-        body (Union['MethodADUpdate', 'MethodCDUpdate', 'MethodCPTUpdate', 'MethodDEFUpdate',
-            'MethodDPUpdate', 'MethodDTUpdate', 'MethodESAUpdate', 'MethodINCUpdate',
-            'MethodIWUpdate', 'MethodOTHERUpdate', 'MethodPTUpdate', 'MethodPZUpdate',
-            'MethodRCDUpdate', 'MethodROUpdate', 'MethodRPUpdate', 'MethodRSUpdate',
-            'MethodRWSUpdate', 'MethodSAUpdate', 'MethodSLBUpdate', 'MethodSPTUpdate',
-            'MethodSRSUpdate', 'MethodSSUpdate', 'MethodSTIUpdate', 'MethodSVTUpdate',
-            'MethodTOTUpdate', 'MethodTPUpdate', 'MethodTRUpdate', 'MethodWSTUpdate']):
+        body (MethodADUpdate | MethodCDUpdate | MethodCPTUpdate | MethodDEFUpdate | MethodDPUpdate
+            | MethodDTUpdate | MethodESAUpdate | MethodINCUpdate | MethodIWUpdate | MethodOTHERUpdate
+            | MethodPTUpdate | MethodPZUpdate | MethodRCDUpdate | MethodROUpdate | MethodRPUpdate |
+            MethodRSUpdate | MethodRWSUpdate | MethodSAUpdate | MethodSLBUpdate | MethodSPTUpdate |
+            MethodSRSUpdate | MethodSSUpdate | MethodSTIUpdate | MethodSVTUpdate | MethodTOTUpdate |
+            MethodTPUpdate | MethodTRUpdate | MethodWSTUpdate):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]
+        HTTPValidationError | MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC | MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR | MethodWST
     """
 
     return sync_detailed(
@@ -745,70 +723,64 @@ async def asyncio_detailed(
     method_id: UUID,
     *,
     client: AuthenticatedClient,
-    body: Union[
-        "MethodADUpdate",
-        "MethodCDUpdate",
-        "MethodCPTUpdate",
-        "MethodDEFUpdate",
-        "MethodDPUpdate",
-        "MethodDTUpdate",
-        "MethodESAUpdate",
-        "MethodINCUpdate",
-        "MethodIWUpdate",
-        "MethodOTHERUpdate",
-        "MethodPTUpdate",
-        "MethodPZUpdate",
-        "MethodRCDUpdate",
-        "MethodROUpdate",
-        "MethodRPUpdate",
-        "MethodRSUpdate",
-        "MethodRWSUpdate",
-        "MethodSAUpdate",
-        "MethodSLBUpdate",
-        "MethodSPTUpdate",
-        "MethodSRSUpdate",
-        "MethodSSUpdate",
-        "MethodSTIUpdate",
-        "MethodSVTUpdate",
-        "MethodTOTUpdate",
-        "MethodTPUpdate",
-        "MethodTRUpdate",
-        "MethodWSTUpdate",
-    ],
+    body: MethodADUpdate
+    | MethodCDUpdate
+    | MethodCPTUpdate
+    | MethodDEFUpdate
+    | MethodDPUpdate
+    | MethodDTUpdate
+    | MethodESAUpdate
+    | MethodINCUpdate
+    | MethodIWUpdate
+    | MethodOTHERUpdate
+    | MethodPTUpdate
+    | MethodPZUpdate
+    | MethodRCDUpdate
+    | MethodROUpdate
+    | MethodRPUpdate
+    | MethodRSUpdate
+    | MethodRWSUpdate
+    | MethodSAUpdate
+    | MethodSLBUpdate
+    | MethodSPTUpdate
+    | MethodSRSUpdate
+    | MethodSSUpdate
+    | MethodSTIUpdate
+    | MethodSVTUpdate
+    | MethodTOTUpdate
+    | MethodTPUpdate
+    | MethodTRUpdate
+    | MethodWSTUpdate,
 ) -> Response[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-        ],
-    ]
+    HTTPValidationError
+    | MethodAD
+    | MethodCD
+    | MethodCPT
+    | MethodDEF
+    | MethodDP
+    | MethodDT
+    | MethodESA
+    | MethodINC
+    | MethodIW
+    | MethodOTHER
+    | MethodPT
+    | MethodPZ
+    | MethodRCD
+    | MethodRO
+    | MethodRP
+    | MethodRS
+    | MethodRWS
+    | MethodSA
+    | MethodSLB
+    | MethodSPT
+    | MethodSRS
+    | MethodSS
+    | MethodSTI
+    | MethodSVT
+    | MethodTOT
+    | MethodTP
+    | MethodTR
+    | MethodWST
 ]:
     """Update Method For Location
 
@@ -818,20 +790,19 @@ async def asyncio_detailed(
         project_id (str):
         location_id (UUID):
         method_id (UUID):
-        body (Union['MethodADUpdate', 'MethodCDUpdate', 'MethodCPTUpdate', 'MethodDEFUpdate',
-            'MethodDPUpdate', 'MethodDTUpdate', 'MethodESAUpdate', 'MethodINCUpdate',
-            'MethodIWUpdate', 'MethodOTHERUpdate', 'MethodPTUpdate', 'MethodPZUpdate',
-            'MethodRCDUpdate', 'MethodROUpdate', 'MethodRPUpdate', 'MethodRSUpdate',
-            'MethodRWSUpdate', 'MethodSAUpdate', 'MethodSLBUpdate', 'MethodSPTUpdate',
-            'MethodSRSUpdate', 'MethodSSUpdate', 'MethodSTIUpdate', 'MethodSVTUpdate',
-            'MethodTOTUpdate', 'MethodTPUpdate', 'MethodTRUpdate', 'MethodWSTUpdate']):
+        body (MethodADUpdate | MethodCDUpdate | MethodCPTUpdate | MethodDEFUpdate | MethodDPUpdate
+            | MethodDTUpdate | MethodESAUpdate | MethodINCUpdate | MethodIWUpdate | MethodOTHERUpdate
+            | MethodPTUpdate | MethodPZUpdate | MethodRCDUpdate | MethodROUpdate | MethodRPUpdate |
+            MethodRSUpdate | MethodRWSUpdate | MethodSAUpdate | MethodSLBUpdate | MethodSPTUpdate |
+            MethodSRSUpdate | MethodSSUpdate | MethodSTIUpdate | MethodSVTUpdate | MethodTOTUpdate |
+            MethodTPUpdate | MethodTRUpdate | MethodWSTUpdate):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]]
+        Response[HTTPValidationError | MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC | MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR | MethodWST]
     """
 
     kwargs = _get_kwargs(
@@ -852,71 +823,66 @@ async def asyncio(
     method_id: UUID,
     *,
     client: AuthenticatedClient,
-    body: Union[
-        "MethodADUpdate",
-        "MethodCDUpdate",
-        "MethodCPTUpdate",
-        "MethodDEFUpdate",
-        "MethodDPUpdate",
-        "MethodDTUpdate",
-        "MethodESAUpdate",
-        "MethodINCUpdate",
-        "MethodIWUpdate",
-        "MethodOTHERUpdate",
-        "MethodPTUpdate",
-        "MethodPZUpdate",
-        "MethodRCDUpdate",
-        "MethodROUpdate",
-        "MethodRPUpdate",
-        "MethodRSUpdate",
-        "MethodRWSUpdate",
-        "MethodSAUpdate",
-        "MethodSLBUpdate",
-        "MethodSPTUpdate",
-        "MethodSRSUpdate",
-        "MethodSSUpdate",
-        "MethodSTIUpdate",
-        "MethodSVTUpdate",
-        "MethodTOTUpdate",
-        "MethodTPUpdate",
-        "MethodTRUpdate",
-        "MethodWSTUpdate",
-    ],
-) -> Optional[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-        ],
-    ]
-]:
+    body: MethodADUpdate
+    | MethodCDUpdate
+    | MethodCPTUpdate
+    | MethodDEFUpdate
+    | MethodDPUpdate
+    | MethodDTUpdate
+    | MethodESAUpdate
+    | MethodINCUpdate
+    | MethodIWUpdate
+    | MethodOTHERUpdate
+    | MethodPTUpdate
+    | MethodPZUpdate
+    | MethodRCDUpdate
+    | MethodROUpdate
+    | MethodRPUpdate
+    | MethodRSUpdate
+    | MethodRWSUpdate
+    | MethodSAUpdate
+    | MethodSLBUpdate
+    | MethodSPTUpdate
+    | MethodSRSUpdate
+    | MethodSSUpdate
+    | MethodSTIUpdate
+    | MethodSVTUpdate
+    | MethodTOTUpdate
+    | MethodTPUpdate
+    | MethodTRUpdate
+    | MethodWSTUpdate,
+) -> (
+    HTTPValidationError
+    | MethodAD
+    | MethodCD
+    | MethodCPT
+    | MethodDEF
+    | MethodDP
+    | MethodDT
+    | MethodESA
+    | MethodINC
+    | MethodIW
+    | MethodOTHER
+    | MethodPT
+    | MethodPZ
+    | MethodRCD
+    | MethodRO
+    | MethodRP
+    | MethodRS
+    | MethodRWS
+    | MethodSA
+    | MethodSLB
+    | MethodSPT
+    | MethodSRS
+    | MethodSS
+    | MethodSTI
+    | MethodSVT
+    | MethodTOT
+    | MethodTP
+    | MethodTR
+    | MethodWST
+    | None
+):
     """Update Method For Location
 
      Update method
@@ -925,20 +891,19 @@ async def asyncio(
         project_id (str):
         location_id (UUID):
         method_id (UUID):
-        body (Union['MethodADUpdate', 'MethodCDUpdate', 'MethodCPTUpdate', 'MethodDEFUpdate',
-            'MethodDPUpdate', 'MethodDTUpdate', 'MethodESAUpdate', 'MethodINCUpdate',
-            'MethodIWUpdate', 'MethodOTHERUpdate', 'MethodPTUpdate', 'MethodPZUpdate',
-            'MethodRCDUpdate', 'MethodROUpdate', 'MethodRPUpdate', 'MethodRSUpdate',
-            'MethodRWSUpdate', 'MethodSAUpdate', 'MethodSLBUpdate', 'MethodSPTUpdate',
-            'MethodSRSUpdate', 'MethodSSUpdate', 'MethodSTIUpdate', 'MethodSVTUpdate',
-            'MethodTOTUpdate', 'MethodTPUpdate', 'MethodTRUpdate', 'MethodWSTUpdate']):
+        body (MethodADUpdate | MethodCDUpdate | MethodCPTUpdate | MethodDEFUpdate | MethodDPUpdate
+            | MethodDTUpdate | MethodESAUpdate | MethodINCUpdate | MethodIWUpdate | MethodOTHERUpdate
+            | MethodPTUpdate | MethodPZUpdate | MethodRCDUpdate | MethodROUpdate | MethodRPUpdate |
+            MethodRSUpdate | MethodRWSUpdate | MethodSAUpdate | MethodSLBUpdate | MethodSPTUpdate |
+            MethodSRSUpdate | MethodSSUpdate | MethodSTIUpdate | MethodSVTUpdate | MethodTOTUpdate |
+            MethodTPUpdate | MethodTRUpdate | MethodWSTUpdate):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]
+        HTTPValidationError | MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC | MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR | MethodWST
     """
 
     return (
