@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union, cast
+from typing import Any, cast
 from uuid import UUID
 
 import httpx
@@ -62,78 +62,75 @@ def _get_kwargs(
 
 
 def _parse_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-            None,
-        ],
-    ]
-]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> (
+    HTTPValidationError
+    | MethodAD
+    | MethodCD
+    | MethodCPT
+    | MethodDEF
+    | MethodDP
+    | MethodDT
+    | MethodESA
+    | MethodINC
+    | MethodIW
+    | MethodOTHER
+    | MethodPT
+    | MethodPZ
+    | MethodRCD
+    | MethodRO
+    | MethodRP
+    | MethodRS
+    | MethodRWS
+    | MethodSA
+    | MethodSLB
+    | MethodSPT
+    | MethodSRS
+    | MethodSS
+    | MethodSTI
+    | MethodSVT
+    | MethodTOT
+    | MethodTP
+    | MethodTR
+    | MethodWST
+    | None
+    | None
+):
     if response.status_code == 201:
 
         def _parse_response_201(
             data: object,
-        ) -> Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-            None,
-        ]:
+        ) -> (
+            MethodAD
+            | MethodCD
+            | MethodCPT
+            | MethodDEF
+            | MethodDP
+            | MethodDT
+            | MethodESA
+            | MethodINC
+            | MethodIW
+            | MethodOTHER
+            | MethodPT
+            | MethodPZ
+            | MethodRCD
+            | MethodRO
+            | MethodRP
+            | MethodRS
+            | MethodRWS
+            | MethodSA
+            | MethodSLB
+            | MethodSPT
+            | MethodSRS
+            | MethodSS
+            | MethodSTI
+            | MethodSVT
+            | MethodTOT
+            | MethodTP
+            | MethodTR
+            | MethodWST
+            | None
+        ):
             if data is None:
                 return data
             try:
@@ -361,37 +358,35 @@ def _parse_response(
             except:  # noqa: E722
                 pass
             return cast(
-                Union[
-                    "MethodAD",
-                    "MethodCD",
-                    "MethodCPT",
-                    "MethodDEF",
-                    "MethodDP",
-                    "MethodDT",
-                    "MethodESA",
-                    "MethodINC",
-                    "MethodIW",
-                    "MethodOTHER",
-                    "MethodPT",
-                    "MethodPZ",
-                    "MethodRCD",
-                    "MethodRO",
-                    "MethodRP",
-                    "MethodRS",
-                    "MethodRWS",
-                    "MethodSA",
-                    "MethodSLB",
-                    "MethodSPT",
-                    "MethodSRS",
-                    "MethodSS",
-                    "MethodSTI",
-                    "MethodSVT",
-                    "MethodTOT",
-                    "MethodTP",
-                    "MethodTR",
-                    "MethodWST",
-                    None,
-                ],
+                MethodAD
+                | MethodCD
+                | MethodCPT
+                | MethodDEF
+                | MethodDP
+                | MethodDT
+                | MethodESA
+                | MethodINC
+                | MethodIW
+                | MethodOTHER
+                | MethodPT
+                | MethodPZ
+                | MethodRCD
+                | MethodRO
+                | MethodRP
+                | MethodRS
+                | MethodRWS
+                | MethodSA
+                | MethodSLB
+                | MethodSPT
+                | MethodSRS
+                | MethodSS
+                | MethodSTI
+                | MethodSVT
+                | MethodTOT
+                | MethodTP
+                | MethodTR
+                | MethodWST
+                | None,
                 data,
             )
 
@@ -411,42 +406,38 @@ def _parse_response(
 
 
 def _build_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+    *, client: AuthenticatedClient | Client, response: httpx.Response
 ) -> Response[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-            None,
-        ],
-    ]
+    HTTPValidationError
+    | MethodAD
+    | MethodCD
+    | MethodCPT
+    | MethodDEF
+    | MethodDP
+    | MethodDT
+    | MethodESA
+    | MethodINC
+    | MethodIW
+    | MethodOTHER
+    | MethodPT
+    | MethodPZ
+    | MethodRCD
+    | MethodRO
+    | MethodRP
+    | MethodRS
+    | MethodRWS
+    | MethodSA
+    | MethodSLB
+    | MethodSPT
+    | MethodSRS
+    | MethodSS
+    | MethodSTI
+    | MethodSVT
+    | MethodTOT
+    | MethodTP
+    | MethodTR
+    | MethodWST
+    | None
 ]:
     return Response(
         status_code=HTTPStatus(response.status_code),
@@ -464,40 +455,36 @@ def sync_detailed(
     client: AuthenticatedClient,
     body: BodyUploadFileProjectsProjectIdLocationsLocationIdMethodsMethodIdUploadPost,
 ) -> Response[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-            None,
-        ],
-    ]
+    HTTPValidationError
+    | MethodAD
+    | MethodCD
+    | MethodCPT
+    | MethodDEF
+    | MethodDP
+    | MethodDT
+    | MethodESA
+    | MethodINC
+    | MethodIW
+    | MethodOTHER
+    | MethodPT
+    | MethodPZ
+    | MethodRCD
+    | MethodRO
+    | MethodRP
+    | MethodRS
+    | MethodRWS
+    | MethodSA
+    | MethodSLB
+    | MethodSPT
+    | MethodSRS
+    | MethodSS
+    | MethodSTI
+    | MethodSVT
+    | MethodTOT
+    | MethodTP
+    | MethodTR
+    | MethodWST
+    | None
 ]:
     r"""Upload File
 
@@ -521,7 +508,7 @@ def sync_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST', None]]]
+        Response[HTTPValidationError | MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC | MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR | MethodWST | None]
     """
 
     kwargs = _get_kwargs(
@@ -545,42 +532,39 @@ def sync(
     *,
     client: AuthenticatedClient,
     body: BodyUploadFileProjectsProjectIdLocationsLocationIdMethodsMethodIdUploadPost,
-) -> Optional[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-            None,
-        ],
-    ]
-]:
+) -> (
+    HTTPValidationError
+    | MethodAD
+    | MethodCD
+    | MethodCPT
+    | MethodDEF
+    | MethodDP
+    | MethodDT
+    | MethodESA
+    | MethodINC
+    | MethodIW
+    | MethodOTHER
+    | MethodPT
+    | MethodPZ
+    | MethodRCD
+    | MethodRO
+    | MethodRP
+    | MethodRS
+    | MethodRWS
+    | MethodSA
+    | MethodSLB
+    | MethodSPT
+    | MethodSRS
+    | MethodSS
+    | MethodSTI
+    | MethodSVT
+    | MethodTOT
+    | MethodTP
+    | MethodTR
+    | MethodWST
+    | None
+    | None
+):
     r"""Upload File
 
      Upload method file.
@@ -603,7 +587,7 @@ def sync(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST', None]]
+        HTTPValidationError | MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC | MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR | MethodWST | None
     """
 
     return sync_detailed(
@@ -623,40 +607,36 @@ async def asyncio_detailed(
     client: AuthenticatedClient,
     body: BodyUploadFileProjectsProjectIdLocationsLocationIdMethodsMethodIdUploadPost,
 ) -> Response[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-            None,
-        ],
-    ]
+    HTTPValidationError
+    | MethodAD
+    | MethodCD
+    | MethodCPT
+    | MethodDEF
+    | MethodDP
+    | MethodDT
+    | MethodESA
+    | MethodINC
+    | MethodIW
+    | MethodOTHER
+    | MethodPT
+    | MethodPZ
+    | MethodRCD
+    | MethodRO
+    | MethodRP
+    | MethodRS
+    | MethodRWS
+    | MethodSA
+    | MethodSLB
+    | MethodSPT
+    | MethodSRS
+    | MethodSS
+    | MethodSTI
+    | MethodSVT
+    | MethodTOT
+    | MethodTP
+    | MethodTR
+    | MethodWST
+    | None
 ]:
     r"""Upload File
 
@@ -680,7 +660,7 @@ async def asyncio_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST', None]]]
+        Response[HTTPValidationError | MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC | MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR | MethodWST | None]
     """
 
     kwargs = _get_kwargs(
@@ -702,42 +682,39 @@ async def asyncio(
     *,
     client: AuthenticatedClient,
     body: BodyUploadFileProjectsProjectIdLocationsLocationIdMethodsMethodIdUploadPost,
-) -> Optional[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-            None,
-        ],
-    ]
-]:
+) -> (
+    HTTPValidationError
+    | MethodAD
+    | MethodCD
+    | MethodCPT
+    | MethodDEF
+    | MethodDP
+    | MethodDT
+    | MethodESA
+    | MethodINC
+    | MethodIW
+    | MethodOTHER
+    | MethodPT
+    | MethodPZ
+    | MethodRCD
+    | MethodRO
+    | MethodRP
+    | MethodRS
+    | MethodRWS
+    | MethodSA
+    | MethodSLB
+    | MethodSPT
+    | MethodSRS
+    | MethodSS
+    | MethodSTI
+    | MethodSVT
+    | MethodTOT
+    | MethodTP
+    | MethodTR
+    | MethodWST
+    | None
+    | None
+):
     r"""Upload File
 
      Upload method file.
@@ -760,7 +737,7 @@ async def asyncio(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST', None]]
+        HTTPValidationError | MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC | MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR | MethodWST | None
     """
 
     return (
