@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any
 
 import httpx
 
@@ -14,11 +14,11 @@ from ...types import UNSET, Response, Unset
 def _get_kwargs(
     organization_id: str,
     *,
-    file_types: Union[Unset, list[FileType]] = UNSET,
+    file_types: list[FileType] | Unset = UNSET,
 ) -> dict[str, Any]:
     params: dict[str, Any] = {}
 
-    json_file_types: Union[Unset, list[str]] = UNSET
+    json_file_types: list[str] | Unset = UNSET
     if not isinstance(file_types, Unset):
         json_file_types = []
         for file_types_item_data in file_types:
@@ -39,8 +39,8 @@ def _get_kwargs(
 
 
 def _parse_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[Union[HTTPValidationError, list["File"]]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> HTTPValidationError | list[File] | None:
     if response.status_code == 200:
         response_200 = []
         _response_200 = response.json()
@@ -63,8 +63,8 @@ def _parse_response(
 
 
 def _build_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Response[Union[HTTPValidationError, list["File"]]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> Response[HTTPValidationError | list[File]]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -77,8 +77,8 @@ def sync_detailed(
     organization_id: str,
     *,
     client: AuthenticatedClient,
-    file_types: Union[Unset, list[FileType]] = UNSET,
-) -> Response[Union[HTTPValidationError, list["File"]]]:
+    file_types: list[FileType] | Unset = UNSET,
+) -> Response[HTTPValidationError | list[File]]:
     """Get Files In Organization
 
      Get all database file objects that are directly attached to the specified organization with
@@ -91,14 +91,14 @@ def sync_detailed(
 
     Args:
         organization_id (str):
-        file_types (Union[Unset, list[FileType]]):
+        file_types (list[FileType] | Unset):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, list['File']]]
+        Response[HTTPValidationError | list[File]]
     """
 
     kwargs = _get_kwargs(
@@ -117,8 +117,8 @@ def sync(
     organization_id: str,
     *,
     client: AuthenticatedClient,
-    file_types: Union[Unset, list[FileType]] = UNSET,
-) -> Optional[Union[HTTPValidationError, list["File"]]]:
+    file_types: list[FileType] | Unset = UNSET,
+) -> HTTPValidationError | list[File] | None:
     """Get Files In Organization
 
      Get all database file objects that are directly attached to the specified organization with
@@ -131,14 +131,14 @@ def sync(
 
     Args:
         organization_id (str):
-        file_types (Union[Unset, list[FileType]]):
+        file_types (list[FileType] | Unset):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, list['File']]
+        HTTPValidationError | list[File]
     """
 
     return sync_detailed(
@@ -152,8 +152,8 @@ async def asyncio_detailed(
     organization_id: str,
     *,
     client: AuthenticatedClient,
-    file_types: Union[Unset, list[FileType]] = UNSET,
-) -> Response[Union[HTTPValidationError, list["File"]]]:
+    file_types: list[FileType] | Unset = UNSET,
+) -> Response[HTTPValidationError | list[File]]:
     """Get Files In Organization
 
      Get all database file objects that are directly attached to the specified organization with
@@ -166,14 +166,14 @@ async def asyncio_detailed(
 
     Args:
         organization_id (str):
-        file_types (Union[Unset, list[FileType]]):
+        file_types (list[FileType] | Unset):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, list['File']]]
+        Response[HTTPValidationError | list[File]]
     """
 
     kwargs = _get_kwargs(
@@ -190,8 +190,8 @@ async def asyncio(
     organization_id: str,
     *,
     client: AuthenticatedClient,
-    file_types: Union[Unset, list[FileType]] = UNSET,
-) -> Optional[Union[HTTPValidationError, list["File"]]]:
+    file_types: list[FileType] | Unset = UNSET,
+) -> HTTPValidationError | list[File] | None:
     """Get Files In Organization
 
      Get all database file objects that are directly attached to the specified organization with
@@ -204,14 +204,14 @@ async def asyncio(
 
     Args:
         organization_id (str):
-        file_types (Union[Unset, list[FileType]]):
+        file_types (list[FileType] | Unset):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, list['File']]
+        HTTPValidationError | list[File]
     """
 
     return (
