@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any
 
 import httpx
 
@@ -23,9 +23,8 @@ def _get_kwargs(
         "url": f"/organizations/{organization_id}",
     }
 
-    _body = body.to_dict()
+    _kwargs["json"] = body.to_dict()
 
-    _kwargs["json"] = _body
     headers["Content-Type"] = "application/json"
 
     _kwargs["headers"] = headers
@@ -33,16 +32,18 @@ def _get_kwargs(
 
 
 def _parse_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[Union[HTTPValidationError, Organization]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> HTTPValidationError | Organization | None:
     if response.status_code == 200:
         response_200 = Organization.from_dict(response.json())
 
         return response_200
+
     if response.status_code == 422:
         response_422 = HTTPValidationError.from_dict(response.json())
 
         return response_422
+
     if client.raise_on_unexpected_status:
         raise errors.UnexpectedStatus(response.status_code, response.content)
     else:
@@ -50,8 +51,8 @@ def _parse_response(
 
 
 def _build_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Response[Union[HTTPValidationError, Organization]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> Response[HTTPValidationError | Organization]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -65,7 +66,7 @@ def sync_detailed(
     *,
     client: AuthenticatedClient,
     body: OrganizationUpdate,
-) -> Response[Union[HTTPValidationError, Organization]]:
+) -> Response[HTTPValidationError | Organization]:
     """Update Organization
 
      Update an organization with passed organization_in.
@@ -79,7 +80,7 @@ def sync_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, Organization]]
+        Response[HTTPValidationError | Organization]
     """
 
     kwargs = _get_kwargs(
@@ -99,7 +100,7 @@ def sync(
     *,
     client: AuthenticatedClient,
     body: OrganizationUpdate,
-) -> Optional[Union[HTTPValidationError, Organization]]:
+) -> HTTPValidationError | Organization | None:
     """Update Organization
 
      Update an organization with passed organization_in.
@@ -113,7 +114,7 @@ def sync(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, Organization]
+        HTTPValidationError | Organization
     """
 
     return sync_detailed(
@@ -128,7 +129,7 @@ async def asyncio_detailed(
     *,
     client: AuthenticatedClient,
     body: OrganizationUpdate,
-) -> Response[Union[HTTPValidationError, Organization]]:
+) -> Response[HTTPValidationError | Organization]:
     """Update Organization
 
      Update an organization with passed organization_in.
@@ -142,7 +143,7 @@ async def asyncio_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, Organization]]
+        Response[HTTPValidationError | Organization]
     """
 
     kwargs = _get_kwargs(
@@ -160,7 +161,7 @@ async def asyncio(
     *,
     client: AuthenticatedClient,
     body: OrganizationUpdate,
-) -> Optional[Union[HTTPValidationError, Organization]]:
+) -> HTTPValidationError | Organization | None:
     """Update Organization
 
      Update an organization with passed organization_in.
@@ -174,7 +175,7 @@ async def asyncio(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, Organization]
+        HTTPValidationError | Organization
     """
 
     return (
