@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any
 
 import httpx
 
@@ -32,8 +32,8 @@ def _get_kwargs(
 
 
 def _parse_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[Union[HTTPValidationError, WebMapService]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> HTTPValidationError | WebMapService | None:
     if response.status_code == 201:
         response_201 = WebMapService.from_dict(response.json())
 
@@ -51,8 +51,8 @@ def _parse_response(
 
 
 def _build_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Response[Union[HTTPValidationError, WebMapService]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> Response[HTTPValidationError | WebMapService]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -66,7 +66,7 @@ def sync_detailed(
     *,
     client: AuthenticatedClient,
     body: WebMapServiceCreate,
-) -> Response[Union[HTTPValidationError, WebMapService]]:
+) -> Response[HTTPValidationError | WebMapService]:
     """Create a Web Map Service for a Project
 
      Create a Web Map Service.
@@ -80,7 +80,7 @@ def sync_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, WebMapService]]
+        Response[HTTPValidationError | WebMapService]
     """
 
     kwargs = _get_kwargs(
@@ -100,7 +100,7 @@ def sync(
     *,
     client: AuthenticatedClient,
     body: WebMapServiceCreate,
-) -> Optional[Union[HTTPValidationError, WebMapService]]:
+) -> HTTPValidationError | WebMapService | None:
     """Create a Web Map Service for a Project
 
      Create a Web Map Service.
@@ -114,7 +114,7 @@ def sync(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, WebMapService]
+        HTTPValidationError | WebMapService
     """
 
     return sync_detailed(
@@ -129,7 +129,7 @@ async def asyncio_detailed(
     *,
     client: AuthenticatedClient,
     body: WebMapServiceCreate,
-) -> Response[Union[HTTPValidationError, WebMapService]]:
+) -> Response[HTTPValidationError | WebMapService]:
     """Create a Web Map Service for a Project
 
      Create a Web Map Service.
@@ -143,7 +143,7 @@ async def asyncio_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, WebMapService]]
+        Response[HTTPValidationError | WebMapService]
     """
 
     kwargs = _get_kwargs(
@@ -161,7 +161,7 @@ async def asyncio(
     *,
     client: AuthenticatedClient,
     body: WebMapServiceCreate,
-) -> Optional[Union[HTTPValidationError, WebMapService]]:
+) -> HTTPValidationError | WebMapService | None:
     """Create a Web Map Service for a Project
 
      Create a Web Map Service.
@@ -175,7 +175,7 @@ async def asyncio(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, WebMapService]
+        HTTPValidationError | WebMapService
     """
 
     return (
