@@ -4,10 +4,10 @@ from .application_class_enum import ApplicationClassEnum
 from .background_map_layer import BackgroundMapLayer
 from .bedrock_info import BedrockInfo
 from .bedrock_type import BedrockType
+from .body_create_shape_projects_project_id_shapes_post import BodyCreateShapeProjectsProjectIdShapesPost
 from .body_queue_locations_to_project_projects_project_id_locations_queue_post import (
     BodyQueueLocationsToProjectProjectsProjectIdLocationsQueuePost,
 )
-from .body_submit_shape_projects_project_id_shapes_post import BodySubmitShapeProjectsProjectIdShapesPost
 from .body_upload_file_projects_project_id_locations_location_id_methods_method_id_upload_post import (
     BodyUploadFileProjectsProjectIdLocationsLocationIdMethodsMethodIdUploadPost,
 )
@@ -37,6 +37,7 @@ from .create_cross_section_lines_projects_project_id_cross_sections_lines_format
 from .cross_section import CrossSection
 from .cross_section_create import CrossSectionCreate
 from .cross_section_update import CrossSectionUpdate
+from .crs_info import CRSInfo
 from .date_format import DateFormat
 from .dp_type import DPType
 from .export import Export
@@ -116,6 +117,7 @@ from .method_min import MethodMin
 from .method_other import MethodOTHER
 from .method_other_create import MethodOTHERCreate
 from .method_other_update import MethodOTHERUpdate
+from .method_plot_format import MethodPlotFormat
 from .method_pt import MethodPT
 from .method_pt_create import MethodPTCreate
 from .method_pt_update import MethodPTUpdate
@@ -270,8 +272,8 @@ __all__ = (
     "BackgroundMapLayer",
     "BedrockInfo",
     "BedrockType",
+    "BodyCreateShapeProjectsProjectIdShapesPost",
     "BodyQueueLocationsToProjectProjectsProjectIdLocationsQueuePost",
-    "BodySubmitShapeProjectsProjectIdShapesPost",
     "BodyUploadFileProjectsProjectIdLocationsLocationIdMethodsMethodIdUploadPost",
     "BodyUploadFileToLocationProjectsProjectIdLocationsLocationIdUploadPost",
     "BodyUploadFileToOrganizationOrganizationsOrganizationIdUploadPost",
@@ -287,6 +289,7 @@ __all__ = (
     "CrossSection",
     "CrossSectionCreate",
     "CrossSectionUpdate",
+    "CRSInfo",
     "DateFormat",
     "DPType",
     "Export",
@@ -364,6 +367,7 @@ __all__ = (
     "MethodOTHER",
     "MethodOTHERCreate",
     "MethodOTHERUpdate",
+    "MethodPlotFormat",
     "MethodPT",
     "MethodPTCreate",
     "MethodPTUpdate",
