@@ -1,10 +1,13 @@
+from __future__ import annotations
+
 from collections.abc import Mapping
 from io import BytesIO
-from typing import Any, TypeVar, Union, cast
+from typing import Any, TypeVar, cast
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
 
+from .. import types
 from ..types import UNSET, File, Unset
 
 T = TypeVar("T", bound="BodyUploadLocationsToProjectProjectsProjectIdLocationsUploadPost")
@@ -15,17 +18,17 @@ class BodyUploadLocationsToProjectProjectsProjectIdLocationsUploadPost:
     """
     Attributes:
         file (File):
-        comment (Union[None, Unset, str]):  Default: ''.
+        comment (None | str | Unset):  Default: ''.
     """
 
     file: File
-    comment: Union[None, Unset, str] = ""
+    comment: None | str | Unset = ""
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
         file = self.file.to_tuple()
 
-        comment: Union[None, Unset, str]
+        comment: None | str | Unset
         if isinstance(self.comment, Unset):
             comment = UNSET
         else:
@@ -43,43 +46,33 @@ class BodyUploadLocationsToProjectProjectsProjectIdLocationsUploadPost:
 
         return field_dict
 
-    def to_multipart(self) -> dict[str, Any]:
-        file = self.file.to_tuple()
+    def to_multipart(self) -> types.RequestFiles:
+        files: types.RequestFiles = []
 
-        comment: Union[Unset, tuple[None, bytes, str]]
+        files.append(("file", self.file.to_tuple()))
 
-        if isinstance(self.comment, Unset):
-            comment = UNSET
-        elif isinstance(self.comment, str):
-            comment = (None, str(self.comment).encode(), "text/plain")
-        else:
-            comment = (None, str(self.comment).encode(), "text/plain")
+        if not isinstance(self.comment, Unset):
+            if isinstance(self.comment, str):
+                files.append(("comment", (None, str(self.comment).encode(), "text/plain")))
+            else:
+                files.append(("comment", (None, str(self.comment).encode(), "text/plain")))
 
-        field_dict: dict[str, Any] = {}
         for prop_name, prop in self.additional_properties.items():
-            field_dict[prop_name] = (None, str(prop).encode(), "text/plain")
+            files.append((prop_name, (None, str(prop).encode(), "text/plain")))
 
-        field_dict.update(
-            {
-                "file": file,
-            }
-        )
-        if comment is not UNSET:
-            field_dict["comment"] = comment
-
-        return field_dict
+        return files
 
     @classmethod
     def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
         d = dict(src_dict)
         file = File(payload=BytesIO(d.pop("file")))
 
-        def _parse_comment(data: object) -> Union[None, Unset, str]:
+        def _parse_comment(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         comment = _parse_comment(d.pop("comment", UNSET))
 
