@@ -1,5 +1,8 @@
+from __future__ import annotations
+
 import datetime
-from typing import Any, TypeVar, Union, cast
+from collections.abc import Mapping
+from typing import Any, TypeVar, cast
 from uuid import UUID
 
 from attrs import define as _attrs_define
@@ -17,61 +20,62 @@ class Export:
     """
     Attributes:
         export_type (ExportType):
-        location_ids (Union[Unset, list[UUID]]): Used when export_type is one of `LocationKOF`, `LocationXLS`
-        file_ids (Union[Unset, list[UUID]]): Used when export_type is `ProjectFiles`
-        method_status_ids (Union[Unset, list[int]]): Filter methods by status. Empty list means all statuses.
-        method_type_ids (Union[Unset, list[int]]): Filter methods by type. Empty list means all types.
-        srid (Union[None, Unset, int]): Specify the output file coordinate system for KOF and SND export. If not
-            specified, the project coordinate system will be used.
-        method_conducted_from (Union[None, Unset, datetime.datetime]): Filter methods by conducted date from this time
-        method_conducted_to (Union[None, Unset, datetime.datetime]): Filter methods by conducted date from (this time +
-            1 day)
-        swap_x_y (Union[None, Unset, bool]):  Default: False.
+        location_ids (list[UUID] | Unset): Used when export_type is one of `LocationCSV`, `LocationGeoJSON`,
+            `LocationKOF`, `LocationLAS` or `LocationXLS`
+        file_ids (list[UUID] | Unset): Used when export_type is `ProjectFiles`
+        method_status_ids (list[int] | Unset): Filter methods by status. Empty list means all statuses.
+        method_type_ids (list[int] | Unset): Filter methods by type. Empty list means all types.
+        srid (int | None | Unset): Specify the output file coordinate system for KOF and SND export. If not specified,
+            the project coordinate system will be used.
+        method_conducted_from (datetime.datetime | None | Unset): Filter methods by conducted date from this time
+        method_conducted_to (datetime.datetime | None | Unset): Filter methods by conducted date from (this time + 1
+            day)
+        swap_x_y (bool | None | Unset):  Default: False.
     """
 
     export_type: ExportType
-    location_ids: Union[Unset, list[UUID]] = UNSET
-    file_ids: Union[Unset, list[UUID]] = UNSET
-    method_status_ids: Union[Unset, list[int]] = UNSET
-    method_type_ids: Union[Unset, list[int]] = UNSET
-    srid: Union[None, Unset, int] = UNSET
-    method_conducted_from: Union[None, Unset, datetime.datetime] = UNSET
-    method_conducted_to: Union[None, Unset, datetime.datetime] = UNSET
-    swap_x_y: Union[None, Unset, bool] = False
+    location_ids: list[UUID] | Unset = UNSET
+    file_ids: list[UUID] | Unset = UNSET
+    method_status_ids: list[int] | Unset = UNSET
+    method_type_ids: list[int] | Unset = UNSET
+    srid: int | None | Unset = UNSET
+    method_conducted_from: datetime.datetime | None | Unset = UNSET
+    method_conducted_to: datetime.datetime | None | Unset = UNSET
+    swap_x_y: bool | None | Unset = False
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
         export_type = self.export_type.value
 
-        location_ids: Union[Unset, list[str]] = UNSET
+        location_ids: list[str] | Unset = UNSET
         if not isinstance(self.location_ids, Unset):
             location_ids = []
             for location_ids_item_data in self.location_ids:
                 location_ids_item = str(location_ids_item_data)
                 location_ids.append(location_ids_item)
 
-        file_ids: Union[Unset, list[str]] = UNSET
+        file_ids: list[str] | Unset = UNSET
         if not isinstance(self.file_ids, Unset):
             file_ids = []
             for file_ids_item_data in self.file_ids:
                 file_ids_item = str(file_ids_item_data)
                 file_ids.append(file_ids_item)
 
-        method_status_ids: Union[Unset, list[int]] = UNSET
+        method_status_ids: list[int] | Unset = UNSET
         if not isinstance(self.method_status_ids, Unset):
             method_status_ids = self.method_status_ids
 
-        method_type_ids: Union[Unset, list[int]] = UNSET
+        method_type_ids: list[int] | Unset = UNSET
         if not isinstance(self.method_type_ids, Unset):
             method_type_ids = self.method_type_ids
 
-        srid: Union[None, Unset, int]
+        srid: int | None | Unset
         if isinstance(self.srid, Unset):
             srid = UNSET
         else:
             srid = self.srid
 
-        method_conducted_from: Union[None, Unset, str]
+        method_conducted_from: None | str | Unset
         if isinstance(self.method_conducted_from, Unset):
             method_conducted_from = UNSET
         elif isinstance(self.method_conducted_from, datetime.datetime):
@@ -79,7 +83,7 @@ class Export:
         else:
             method_conducted_from = self.method_conducted_from
 
-        method_conducted_to: Union[None, Unset, str]
+        method_conducted_to: None | str | Unset
         if isinstance(self.method_conducted_to, Unset):
             method_conducted_to = UNSET
         elif isinstance(self.method_conducted_to, datetime.datetime):
@@ -87,7 +91,7 @@ class Export:
         else:
             method_conducted_to = self.method_conducted_to
 
-        swap_x_y: Union[None, Unset, bool]
+        swap_x_y: bool | None | Unset
         if isinstance(self.swap_x_y, Unset):
             swap_x_y = UNSET
         else:
@@ -120,8 +124,8 @@ class Export:
         return field_dict
 
     @classmethod
-    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
-        d = src_dict.copy()
+    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
+        d = dict(src_dict)
         export_type = ExportType(d.pop("export_type"))
 
         location_ids = []
@@ -142,16 +146,16 @@ class Export:
 
         method_type_ids = cast(list[int], d.pop("method_type_ids", UNSET))
 
-        def _parse_srid(data: object) -> Union[None, Unset, int]:
+        def _parse_srid(data: object) -> int | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, int], data)
+            return cast(int | None | Unset, data)
 
         srid = _parse_srid(d.pop("srid", UNSET))
 
-        def _parse_method_conducted_from(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_method_conducted_from(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -164,11 +168,11 @@ class Export:
                 return method_conducted_from_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         method_conducted_from = _parse_method_conducted_from(d.pop("method_conducted_from", UNSET))
 
-        def _parse_method_conducted_to(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_method_conducted_to(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -181,16 +185,16 @@ class Export:
                 return method_conducted_to_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         method_conducted_to = _parse_method_conducted_to(d.pop("method_conducted_to", UNSET))
 
-        def _parse_swap_x_y(data: object) -> Union[None, Unset, bool]:
+        def _parse_swap_x_y(data: object) -> bool | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, bool], data)
+            return cast(bool | None | Unset, data)
 
         swap_x_y = _parse_swap_x_y(d.pop("swap_x_y", UNSET))
 
