@@ -1,5 +1,8 @@
+from __future__ import annotations
+
 import datetime
-from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
+from collections.abc import Mapping
+from typing import TYPE_CHECKING, Any, TypeVar, cast
 from uuid import UUID
 
 from attrs import define as _attrs_define
@@ -23,7 +26,7 @@ class LinkedProjectInfo:
     """
     Example:
         {'external_id': '2020193232', 'height_reference': 'NN2000', 'name': 'Project Name', 'organization_id':
-            'ee5d5c98-b08e-401b-a4f2-7d5b8e65467a', 'project_id': '64de2f57-7ebf-4ed3-aa37-ab65fef6e157', 'srid': 3857}
+            'fff31299-1f3d-48e3-ad70-8c9c37370900', 'project_id': 'e66a377d-3816-4cf8-ad79-d954a3ba632d', 'srid': 3857}
 
     Attributes:
         project_id (UUID):
@@ -34,16 +37,16 @@ class LinkedProjectInfo:
         srid (int):
         number_of_locations (int):
         number_of_active_locations (int):
-        created_at (Union[None, Unset, datetime.datetime]):
-        updated_at (Union[None, Unset, datetime.datetime]):
-        external_id_source (Union[None, Unset, str]):
-        height_reference (Union[HeightReference, None, Unset]):
-        description (Union[None, Unset, str]):
-        tags (Union[None, Unset, list[str]]):
-        organization (Union['OrganizationMin', None, Unset]):
-        effective_role (Union['Role', None, Unset]):
-        last_updated (Union[None, Unset, datetime.datetime]):
-        favorite (Union[Unset, bool]):  Default: False.
+        created_at (datetime.datetime | None | Unset):
+        updated_at (datetime.datetime | None | Unset):
+        external_id_source (None | str | Unset):
+        height_reference (HeightReference | None | Unset):
+        description (None | str | Unset):
+        tags (list[str] | None | Unset):
+        organization (None | OrganizationMin | Unset):
+        effective_role (None | Role | Unset):
+        last_updated (datetime.datetime | None | Unset):
+        favorite (bool | Unset):  Default: False.
     """
 
     project_id: UUID
@@ -54,16 +57,16 @@ class LinkedProjectInfo:
     srid: int
     number_of_locations: int
     number_of_active_locations: int
-    created_at: Union[None, Unset, datetime.datetime] = UNSET
-    updated_at: Union[None, Unset, datetime.datetime] = UNSET
-    external_id_source: Union[None, Unset, str] = UNSET
-    height_reference: Union[HeightReference, None, Unset] = UNSET
-    description: Union[None, Unset, str] = UNSET
-    tags: Union[None, Unset, list[str]] = UNSET
-    organization: Union["OrganizationMin", None, Unset] = UNSET
-    effective_role: Union["Role", None, Unset] = UNSET
-    last_updated: Union[None, Unset, datetime.datetime] = UNSET
-    favorite: Union[Unset, bool] = False
+    created_at: datetime.datetime | None | Unset = UNSET
+    updated_at: datetime.datetime | None | Unset = UNSET
+    external_id_source: None | str | Unset = UNSET
+    height_reference: HeightReference | None | Unset = UNSET
+    description: None | str | Unset = UNSET
+    tags: list[str] | None | Unset = UNSET
+    organization: None | OrganizationMin | Unset = UNSET
+    effective_role: None | Role | Unset = UNSET
+    last_updated: datetime.datetime | None | Unset = UNSET
+    favorite: bool | Unset = False
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
@@ -86,7 +89,7 @@ class LinkedProjectInfo:
 
         number_of_active_locations = self.number_of_active_locations
 
-        created_at: Union[None, Unset, str]
+        created_at: None | str | Unset
         if isinstance(self.created_at, Unset):
             created_at = UNSET
         elif isinstance(self.created_at, datetime.datetime):
@@ -94,7 +97,7 @@ class LinkedProjectInfo:
         else:
             created_at = self.created_at
 
-        updated_at: Union[None, Unset, str]
+        updated_at: None | str | Unset
         if isinstance(self.updated_at, Unset):
             updated_at = UNSET
         elif isinstance(self.updated_at, datetime.datetime):
@@ -102,13 +105,13 @@ class LinkedProjectInfo:
         else:
             updated_at = self.updated_at
 
-        external_id_source: Union[None, Unset, str]
+        external_id_source: None | str | Unset
         if isinstance(self.external_id_source, Unset):
             external_id_source = UNSET
         else:
             external_id_source = self.external_id_source
 
-        height_reference: Union[None, Unset, str]
+        height_reference: None | str | Unset
         if isinstance(self.height_reference, Unset):
             height_reference = UNSET
         elif isinstance(self.height_reference, HeightReference):
@@ -116,13 +119,13 @@ class LinkedProjectInfo:
         else:
             height_reference = self.height_reference
 
-        description: Union[None, Unset, str]
+        description: None | str | Unset
         if isinstance(self.description, Unset):
             description = UNSET
         else:
             description = self.description
 
-        tags: Union[None, Unset, list[str]]
+        tags: list[str] | None | Unset
         if isinstance(self.tags, Unset):
             tags = UNSET
         elif isinstance(self.tags, list):
@@ -131,7 +134,7 @@ class LinkedProjectInfo:
         else:
             tags = self.tags
 
-        organization: Union[None, Unset, dict[str, Any]]
+        organization: dict[str, Any] | None | Unset
         if isinstance(self.organization, Unset):
             organization = UNSET
         elif isinstance(self.organization, OrganizationMin):
@@ -139,7 +142,7 @@ class LinkedProjectInfo:
         else:
             organization = self.organization
 
-        effective_role: Union[None, Unset, dict[str, Any]]
+        effective_role: dict[str, Any] | None | Unset
         if isinstance(self.effective_role, Unset):
             effective_role = UNSET
         elif isinstance(self.effective_role, Role):
@@ -147,7 +150,7 @@ class LinkedProjectInfo:
         else:
             effective_role = self.effective_role
 
-        last_updated: Union[None, Unset, str]
+        last_updated: None | str | Unset
         if isinstance(self.last_updated, Unset):
             last_updated = UNSET
         elif isinstance(self.last_updated, datetime.datetime):
@@ -195,11 +198,11 @@ class LinkedProjectInfo:
         return field_dict
 
     @classmethod
-    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
+    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
         from ..models.organization_min import OrganizationMin
         from ..models.role import Role
 
-        d = src_dict.copy()
+        d = dict(src_dict)
         project_id = UUID(d.pop("project_id"))
 
         external_id = d.pop("external_id")
@@ -216,7 +219,7 @@ class LinkedProjectInfo:
 
         number_of_active_locations = d.pop("number_of_active_locations")
 
-        def _parse_created_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_created_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -229,11 +232,11 @@ class LinkedProjectInfo:
                 return created_at_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         created_at = _parse_created_at(d.pop("created_at", UNSET))
 
-        def _parse_updated_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_updated_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -246,20 +249,20 @@ class LinkedProjectInfo:
                 return updated_at_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         updated_at = _parse_updated_at(d.pop("updated_at", UNSET))
 
-        def _parse_external_id_source(data: object) -> Union[None, Unset, str]:
+        def _parse_external_id_source(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         external_id_source = _parse_external_id_source(d.pop("external_id_source", UNSET))
 
-        def _parse_height_reference(data: object) -> Union[HeightReference, None, Unset]:
+        def _parse_height_reference(data: object) -> HeightReference | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -272,20 +275,20 @@ class LinkedProjectInfo:
                 return height_reference_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[HeightReference, None, Unset], data)
+            return cast(HeightReference | None | Unset, data)
 
         height_reference = _parse_height_reference(d.pop("height_reference", UNSET))
 
-        def _parse_description(data: object) -> Union[None, Unset, str]:
+        def _parse_description(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         description = _parse_description(d.pop("description", UNSET))
 
-        def _parse_tags(data: object) -> Union[None, Unset, list[str]]:
+        def _parse_tags(data: object) -> list[str] | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -298,11 +301,11 @@ class LinkedProjectInfo:
                 return tags_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, Unset, list[str]], data)
+            return cast(list[str] | None | Unset, data)
 
         tags = _parse_tags(d.pop("tags", UNSET))
 
-        def _parse_organization(data: object) -> Union["OrganizationMin", None, Unset]:
+        def _parse_organization(data: object) -> None | OrganizationMin | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -315,11 +318,11 @@ class LinkedProjectInfo:
                 return organization_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union["OrganizationMin", None, Unset], data)
+            return cast(None | OrganizationMin | Unset, data)
 
         organization = _parse_organization(d.pop("organization", UNSET))
 
-        def _parse_effective_role(data: object) -> Union["Role", None, Unset]:
+        def _parse_effective_role(data: object) -> None | Role | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -332,11 +335,11 @@ class LinkedProjectInfo:
                 return effective_role_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union["Role", None, Unset], data)
+            return cast(None | Role | Unset, data)
 
         effective_role = _parse_effective_role(d.pop("effective_role", UNSET))
 
-        def _parse_last_updated(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_last_updated(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -349,7 +352,7 @@ class LinkedProjectInfo:
                 return last_updated_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         last_updated = _parse_last_updated(d.pop("last_updated", UNSET))
 
