@@ -1,6 +1,8 @@
+from __future__ import annotations
+
 import datetime
 from collections.abc import Mapping
-from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
+from typing import TYPE_CHECKING, Any, TypeVar, cast
 from uuid import UUID
 
 from attrs import define as _attrs_define
@@ -76,103 +78,101 @@ T = TypeVar("T", bound="LocationUpdate")
 class LocationUpdate:
     """
     Attributes:
-        project_id (Union[None, UUID, Unset]):
-        location_id (Union[None, UUID, Unset]):
-        iogp_type_id (Union[IOGPTypeEnum, None, Unset]):
-        name (Union[None, Unset, str]):
-        updated_at (Union[None, Unset, datetime.datetime]):
-        updated_by (Union[None, Unset, str]):
-        point_easting (Union[None, Unset, float]):
-        point_northing (Union[None, Unset, float]):
-        point_z (Union[None, Unset, float]):
-        srid (Union[None, Unset, int]):
-        tags (Union[None, Unset, list[str]]):
-        methods (Union[Unset, list[Union['MethodADCreate', 'MethodADUpdate', 'MethodCDCreate', 'MethodCDUpdate',
-            'MethodCPTCreate', 'MethodCPTUpdate', 'MethodDEFCreate', 'MethodDEFUpdate', 'MethodDPCreate', 'MethodDPUpdate',
-            'MethodDTCreate', 'MethodDTUpdate', 'MethodESACreate', 'MethodESAUpdate', 'MethodINCCreate', 'MethodINCUpdate',
-            'MethodIWCreate', 'MethodIWUpdate', 'MethodOTHERCreate', 'MethodOTHERUpdate', 'MethodPTCreate',
-            'MethodPTUpdate', 'MethodPZCreate', 'MethodPZUpdate', 'MethodRCDCreate', 'MethodRCDUpdate', 'MethodROCreate',
-            'MethodROUpdate', 'MethodRPCreate', 'MethodRPUpdate', 'MethodRSCreate', 'MethodRSUpdate', 'MethodRWSCreate',
-            'MethodRWSUpdate', 'MethodSACreate', 'MethodSAUpdate', 'MethodSLBCreate', 'MethodSLBUpdate', 'MethodSPTCreate',
-            'MethodSPTUpdate', 'MethodSRSCreate', 'MethodSRSUpdate', 'MethodSSCreate', 'MethodSSUpdate', 'MethodSTICreate',
-            'MethodSTIUpdate', 'MethodSVTCreate', 'MethodSVTUpdate', 'MethodTOTCreate', 'MethodTOTUpdate', 'MethodTPCreate',
-            'MethodTPUpdate', 'MethodTRCreate', 'MethodTRUpdate', 'MethodWSTCreate', 'MethodWSTUpdate']]]):
+        project_id (None | Unset | UUID):
+        location_id (None | Unset | UUID):
+        iogp_type_id (IOGPTypeEnum | None | Unset):
+        name (None | str | Unset):
+        updated_at (datetime.datetime | None | Unset):
+        updated_by (None | str | Unset):
+        point_easting (float | None | Unset):
+        point_northing (float | None | Unset):
+        point_z (float | None | Unset):
+        srid (int | None | Unset):
+        tags (list[str] | None | Unset):
+        methods (list[MethodADCreate | MethodADUpdate | MethodCDCreate | MethodCDUpdate | MethodCPTCreate |
+            MethodCPTUpdate | MethodDEFCreate | MethodDEFUpdate | MethodDPCreate | MethodDPUpdate | MethodDTCreate |
+            MethodDTUpdate | MethodESACreate | MethodESAUpdate | MethodINCCreate | MethodINCUpdate | MethodIWCreate |
+            MethodIWUpdate | MethodOTHERCreate | MethodOTHERUpdate | MethodPTCreate | MethodPTUpdate | MethodPZCreate |
+            MethodPZUpdate | MethodRCDCreate | MethodRCDUpdate | MethodROCreate | MethodROUpdate | MethodRPCreate |
+            MethodRPUpdate | MethodRSCreate | MethodRSUpdate | MethodRWSCreate | MethodRWSUpdate | MethodSACreate |
+            MethodSAUpdate | MethodSLBCreate | MethodSLBUpdate | MethodSPTCreate | MethodSPTUpdate | MethodSRSCreate |
+            MethodSRSUpdate | MethodSSCreate | MethodSSUpdate | MethodSTICreate | MethodSTIUpdate | MethodSVTCreate |
+            MethodSVTUpdate | MethodTOTCreate | MethodTOTUpdate | MethodTPCreate | MethodTPUpdate | MethodTRCreate |
+            MethodTRUpdate | MethodWSTCreate | MethodWSTUpdate] | Unset):
     """
 
-    project_id: Union[None, UUID, Unset] = UNSET
-    location_id: Union[None, UUID, Unset] = UNSET
-    iogp_type_id: Union[IOGPTypeEnum, None, Unset] = UNSET
-    name: Union[None, Unset, str] = UNSET
-    updated_at: Union[None, Unset, datetime.datetime] = UNSET
-    updated_by: Union[None, Unset, str] = UNSET
-    point_easting: Union[None, Unset, float] = UNSET
-    point_northing: Union[None, Unset, float] = UNSET
-    point_z: Union[None, Unset, float] = UNSET
-    srid: Union[None, Unset, int] = UNSET
-    tags: Union[None, Unset, list[str]] = UNSET
-    methods: Union[
-        Unset,
+    project_id: None | Unset | UUID = UNSET
+    location_id: None | Unset | UUID = UNSET
+    iogp_type_id: IOGPTypeEnum | None | Unset = UNSET
+    name: None | str | Unset = UNSET
+    updated_at: datetime.datetime | None | Unset = UNSET
+    updated_by: None | str | Unset = UNSET
+    point_easting: float | None | Unset = UNSET
+    point_northing: float | None | Unset = UNSET
+    point_z: float | None | Unset = UNSET
+    srid: int | None | Unset = UNSET
+    tags: list[str] | None | Unset = UNSET
+    methods: (
         list[
-            Union[
-                "MethodADCreate",
-                "MethodADUpdate",
-                "MethodCDCreate",
-                "MethodCDUpdate",
-                "MethodCPTCreate",
-                "MethodCPTUpdate",
-                "MethodDEFCreate",
-                "MethodDEFUpdate",
-                "MethodDPCreate",
-                "MethodDPUpdate",
-                "MethodDTCreate",
-                "MethodDTUpdate",
-                "MethodESACreate",
-                "MethodESAUpdate",
-                "MethodINCCreate",
-                "MethodINCUpdate",
-                "MethodIWCreate",
-                "MethodIWUpdate",
-                "MethodOTHERCreate",
-                "MethodOTHERUpdate",
-                "MethodPTCreate",
-                "MethodPTUpdate",
-                "MethodPZCreate",
-                "MethodPZUpdate",
-                "MethodRCDCreate",
-                "MethodRCDUpdate",
-                "MethodROCreate",
-                "MethodROUpdate",
-                "MethodRPCreate",
-                "MethodRPUpdate",
-                "MethodRSCreate",
-                "MethodRSUpdate",
-                "MethodRWSCreate",
-                "MethodRWSUpdate",
-                "MethodSACreate",
-                "MethodSAUpdate",
-                "MethodSLBCreate",
-                "MethodSLBUpdate",
-                "MethodSPTCreate",
-                "MethodSPTUpdate",
-                "MethodSRSCreate",
-                "MethodSRSUpdate",
-                "MethodSSCreate",
-                "MethodSSUpdate",
-                "MethodSTICreate",
-                "MethodSTIUpdate",
-                "MethodSVTCreate",
-                "MethodSVTUpdate",
-                "MethodTOTCreate",
-                "MethodTOTUpdate",
-                "MethodTPCreate",
-                "MethodTPUpdate",
-                "MethodTRCreate",
-                "MethodTRUpdate",
-                "MethodWSTCreate",
-                "MethodWSTUpdate",
-            ]
-        ],
-    ] = UNSET
+            MethodADCreate
+            | MethodADUpdate
+            | MethodCDCreate
+            | MethodCDUpdate
+            | MethodCPTCreate
+            | MethodCPTUpdate
+            | MethodDEFCreate
+            | MethodDEFUpdate
+            | MethodDPCreate
+            | MethodDPUpdate
+            | MethodDTCreate
+            | MethodDTUpdate
+            | MethodESACreate
+            | MethodESAUpdate
+            | MethodINCCreate
+            | MethodINCUpdate
+            | MethodIWCreate
+            | MethodIWUpdate
+            | MethodOTHERCreate
+            | MethodOTHERUpdate
+            | MethodPTCreate
+            | MethodPTUpdate
+            | MethodPZCreate
+            | MethodPZUpdate
+            | MethodRCDCreate
+            | MethodRCDUpdate
+            | MethodROCreate
+            | MethodROUpdate
+            | MethodRPCreate
+            | MethodRPUpdate
+            | MethodRSCreate
+            | MethodRSUpdate
+            | MethodRWSCreate
+            | MethodRWSUpdate
+            | MethodSACreate
+            | MethodSAUpdate
+            | MethodSLBCreate
+            | MethodSLBUpdate
+            | MethodSPTCreate
+            | MethodSPTUpdate
+            | MethodSRSCreate
+            | MethodSRSUpdate
+            | MethodSSCreate
+            | MethodSSUpdate
+            | MethodSTICreate
+            | MethodSTIUpdate
+            | MethodSVTCreate
+            | MethodSVTUpdate
+            | MethodTOTCreate
+            | MethodTOTUpdate
+            | MethodTPCreate
+            | MethodTPUpdate
+            | MethodTRCreate
+            | MethodTRUpdate
+            | MethodWSTCreate
+            | MethodWSTUpdate
+        ]
+        | Unset
+    ) = UNSET
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
@@ -232,7 +232,7 @@ class LocationUpdate:
         from ..models.method_wst_create import MethodWSTCreate
         from ..models.method_wst_update import MethodWSTUpdate
 
-        project_id: Union[None, Unset, str]
+        project_id: None | str | Unset
         if isinstance(self.project_id, Unset):
             project_id = UNSET
         elif isinstance(self.project_id, UUID):
@@ -240,7 +240,7 @@ class LocationUpdate:
         else:
             project_id = self.project_id
 
-        location_id: Union[None, Unset, str]
+        location_id: None | str | Unset
         if isinstance(self.location_id, Unset):
             location_id = UNSET
         elif isinstance(self.location_id, UUID):
@@ -248,7 +248,7 @@ class LocationUpdate:
         else:
             location_id = self.location_id
 
-        iogp_type_id: Union[None, Unset, str]
+        iogp_type_id: None | str | Unset
         if isinstance(self.iogp_type_id, Unset):
             iogp_type_id = UNSET
         elif isinstance(self.iogp_type_id, IOGPTypeEnum):
@@ -256,13 +256,13 @@ class LocationUpdate:
         else:
             iogp_type_id = self.iogp_type_id
 
-        name: Union[None, Unset, str]
+        name: None | str | Unset
         if isinstance(self.name, Unset):
             name = UNSET
         else:
             name = self.name
 
-        updated_at: Union[None, Unset, str]
+        updated_at: None | str | Unset
         if isinstance(self.updated_at, Unset):
             updated_at = UNSET
         elif isinstance(self.updated_at, datetime.datetime):
@@ -270,37 +270,37 @@ class LocationUpdate:
         else:
             updated_at = self.updated_at
 
-        updated_by: Union[None, Unset, str]
+        updated_by: None | str | Unset
         if isinstance(self.updated_by, Unset):
             updated_by = UNSET
         else:
             updated_by = self.updated_by
 
-        point_easting: Union[None, Unset, float]
+        point_easting: float | None | Unset
         if isinstance(self.point_easting, Unset):
             point_easting = UNSET
         else:
             point_easting = self.point_easting
 
-        point_northing: Union[None, Unset, float]
+        point_northing: float | None | Unset
         if isinstance(self.point_northing, Unset):
             point_northing = UNSET
         else:
             point_northing = self.point_northing
 
-        point_z: Union[None, Unset, float]
+        point_z: float | None | Unset
         if isinstance(self.point_z, Unset):
             point_z = UNSET
         else:
             point_z = self.point_z
 
-        srid: Union[None, Unset, int]
+        srid: int | None | Unset
         if isinstance(self.srid, Unset):
             srid = UNSET
         else:
             srid = self.srid
 
-        tags: Union[None, Unset, list[str]]
+        tags: list[str] | None | Unset
         if isinstance(self.tags, Unset):
             tags = UNSET
         elif isinstance(self.tags, list):
@@ -309,7 +309,7 @@ class LocationUpdate:
         else:
             tags = self.tags
 
-        methods: Union[Unset, list[dict[str, Any]]] = UNSET
+        methods: list[dict[str, Any]] | Unset = UNSET
         if not isinstance(self.methods, Unset):
             methods = []
             for methods_item_data in self.methods:
@@ -520,7 +520,7 @@ class LocationUpdate:
 
         d = dict(src_dict)
 
-        def _parse_project_id(data: object) -> Union[None, UUID, Unset]:
+        def _parse_project_id(data: object) -> None | Unset | UUID:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -533,11 +533,11 @@ class LocationUpdate:
                 return project_id_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, UUID, Unset], data)
+            return cast(None | Unset | UUID, data)
 
         project_id = _parse_project_id(d.pop("project_id", UNSET))
 
-        def _parse_location_id(data: object) -> Union[None, UUID, Unset]:
+        def _parse_location_id(data: object) -> None | Unset | UUID:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -550,11 +550,11 @@ class LocationUpdate:
                 return location_id_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, UUID, Unset], data)
+            return cast(None | Unset | UUID, data)
 
         location_id = _parse_location_id(d.pop("location_id", UNSET))
 
-        def _parse_iogp_type_id(data: object) -> Union[IOGPTypeEnum, None, Unset]:
+        def _parse_iogp_type_id(data: object) -> IOGPTypeEnum | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -567,20 +567,20 @@ class LocationUpdate:
                 return iogp_type_id_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[IOGPTypeEnum, None, Unset], data)
+            return cast(IOGPTypeEnum | None | Unset, data)
 
         iogp_type_id = _parse_iogp_type_id(d.pop("iogp_type_id", UNSET))
 
-        def _parse_name(data: object) -> Union[None, Unset, str]:
+        def _parse_name(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         name = _parse_name(d.pop("name", UNSET))
 
-        def _parse_updated_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_updated_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -593,56 +593,56 @@ class LocationUpdate:
                 return updated_at_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         updated_at = _parse_updated_at(d.pop("updated_at", UNSET))
 
-        def _parse_updated_by(data: object) -> Union[None, Unset, str]:
+        def _parse_updated_by(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         updated_by = _parse_updated_by(d.pop("updated_by", UNSET))
 
-        def _parse_point_easting(data: object) -> Union[None, Unset, float]:
+        def _parse_point_easting(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         point_easting = _parse_point_easting(d.pop("point_easting", UNSET))
 
-        def _parse_point_northing(data: object) -> Union[None, Unset, float]:
+        def _parse_point_northing(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         point_northing = _parse_point_northing(d.pop("point_northing", UNSET))
 
-        def _parse_point_z(data: object) -> Union[None, Unset, float]:
+        def _parse_point_z(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         point_z = _parse_point_z(d.pop("point_z", UNSET))
 
-        def _parse_srid(data: object) -> Union[None, Unset, int]:
+        def _parse_srid(data: object) -> int | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, int], data)
+            return cast(int | None | Unset, data)
 
         srid = _parse_srid(d.pop("srid", UNSET))
 
-        def _parse_tags(data: object) -> Union[None, Unset, list[str]]:
+        def _parse_tags(data: object) -> list[str] | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -655,7 +655,7 @@ class LocationUpdate:
                 return tags_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, Unset, list[str]], data)
+            return cast(list[str] | None | Unset, data)
 
         tags = _parse_tags(d.pop("tags", UNSET))
 
@@ -665,64 +665,64 @@ class LocationUpdate:
 
             def _parse_methods_item(
                 data: object,
-            ) -> Union[
-                "MethodADCreate",
-                "MethodADUpdate",
-                "MethodCDCreate",
-                "MethodCDUpdate",
-                "MethodCPTCreate",
-                "MethodCPTUpdate",
-                "MethodDEFCreate",
-                "MethodDEFUpdate",
-                "MethodDPCreate",
-                "MethodDPUpdate",
-                "MethodDTCreate",
-                "MethodDTUpdate",
-                "MethodESACreate",
-                "MethodESAUpdate",
-                "MethodINCCreate",
-                "MethodINCUpdate",
-                "MethodIWCreate",
-                "MethodIWUpdate",
-                "MethodOTHERCreate",
-                "MethodOTHERUpdate",
-                "MethodPTCreate",
-                "MethodPTUpdate",
-                "MethodPZCreate",
-                "MethodPZUpdate",
-                "MethodRCDCreate",
-                "MethodRCDUpdate",
-                "MethodROCreate",
-                "MethodROUpdate",
-                "MethodRPCreate",
-                "MethodRPUpdate",
-                "MethodRSCreate",
-                "MethodRSUpdate",
-                "MethodRWSCreate",
-                "MethodRWSUpdate",
-                "MethodSACreate",
-                "MethodSAUpdate",
-                "MethodSLBCreate",
-                "MethodSLBUpdate",
-                "MethodSPTCreate",
-                "MethodSPTUpdate",
-                "MethodSRSCreate",
-                "MethodSRSUpdate",
-                "MethodSSCreate",
-                "MethodSSUpdate",
-                "MethodSTICreate",
-                "MethodSTIUpdate",
-                "MethodSVTCreate",
-                "MethodSVTUpdate",
-                "MethodTOTCreate",
-                "MethodTOTUpdate",
-                "MethodTPCreate",
-                "MethodTPUpdate",
-                "MethodTRCreate",
-                "MethodTRUpdate",
-                "MethodWSTCreate",
-                "MethodWSTUpdate",
-            ]:
+            ) -> (
+                MethodADCreate
+                | MethodADUpdate
+                | MethodCDCreate
+                | MethodCDUpdate
+                | MethodCPTCreate
+                | MethodCPTUpdate
+                | MethodDEFCreate
+                | MethodDEFUpdate
+                | MethodDPCreate
+                | MethodDPUpdate
+                | MethodDTCreate
+                | MethodDTUpdate
+                | MethodESACreate
+                | MethodESAUpdate
+                | MethodINCCreate
+                | MethodINCUpdate
+                | MethodIWCreate
+                | MethodIWUpdate
+                | MethodOTHERCreate
+                | MethodOTHERUpdate
+                | MethodPTCreate
+                | MethodPTUpdate
+                | MethodPZCreate
+                | MethodPZUpdate
+                | MethodRCDCreate
+                | MethodRCDUpdate
+                | MethodROCreate
+                | MethodROUpdate
+                | MethodRPCreate
+                | MethodRPUpdate
+                | MethodRSCreate
+                | MethodRSUpdate
+                | MethodRWSCreate
+                | MethodRWSUpdate
+                | MethodSACreate
+                | MethodSAUpdate
+                | MethodSLBCreate
+                | MethodSLBUpdate
+                | MethodSPTCreate
+                | MethodSPTUpdate
+                | MethodSRSCreate
+                | MethodSRSUpdate
+                | MethodSSCreate
+                | MethodSSUpdate
+                | MethodSTICreate
+                | MethodSTIUpdate
+                | MethodSVTCreate
+                | MethodSVTUpdate
+                | MethodTOTCreate
+                | MethodTOTUpdate
+                | MethodTPCreate
+                | MethodTPUpdate
+                | MethodTRCreate
+                | MethodTRUpdate
+                | MethodWSTCreate
+                | MethodWSTUpdate
+            ):
                 try:
                     if not isinstance(data, dict):
                         raise TypeError()
