@@ -1,5 +1,8 @@
+from __future__ import annotations
+
 import datetime
-from typing import Any, Literal, TypeVar, Union, cast
+from collections.abc import Mapping
+from typing import Any, Literal, TypeVar, cast
 from uuid import UUID
 
 from attrs import define as _attrs_define
@@ -17,56 +20,56 @@ T = TypeVar("T", bound="MethodDPCreate")
 class MethodDPCreate:
     """
     Attributes:
-        method_id (Union[None, UUID, Unset]):
-        name (Union[Unset, str]):  Default: 'DP'.
-        remarks (Union[None, Unset, str]):
-        method_status_id (Union[Unset, MethodStatusEnum]): (
+        method_id (None | Unset | UUID):
+        name (str | Unset):  Default: 'DP'.
+        remarks (None | str | Unset):
+        method_status_id (MethodStatusEnum | Unset): (
             PLANNED=1,
             READY=2,
             CONDUCTED=3,
             VOIDED=4,
             APPROVED=5,
             )
-        created_at (Union[None, Unset, datetime.datetime]):
-        created_by (Union[None, Unset, str]):
-        updated_at (Union[None, Unset, datetime.datetime]):
-        updated_by (Union[None, Unset, str]):
-        conducted_by (Union[None, Unset, str]):
-        conducted_at (Union[None, Unset, datetime.datetime]):
-        method_type_id (Union[Literal[25], Unset]):  Default: 25.
-        type_ (Union[Unset, DPType]): (Dynamic Probing) DP Type
-        predrilling_depth (Union[None, Unset, float, str]):
-        cone_type (Union[None, Unset, str]):
-        cushion_type (Union[None, Unset, str]):
-        use_damper (Union[None, Unset, bool]):
-        depth_top (Union[None, Unset, float, str]):
-        depth_base (Union[None, Unset, float, str]):
-        stopcode (Union[None, Unset, int]):
+        created_at (datetime.datetime | None | Unset):
+        created_by (None | str | Unset):
+        updated_at (datetime.datetime | None | Unset):
+        updated_by (None | str | Unset):
+        conducted_by (None | str | Unset):
+        conducted_at (datetime.datetime | None | Unset):
+        method_type_id (Literal[25] | Unset):  Default: 25.
+        dynamic_probing_type (DPType | None | Unset):
+        predrilling_depth (float | None | str | Unset):
+        cone_type (None | str | Unset):
+        cushion_type (None | str | Unset):
+        use_damper (bool | None | Unset):
+        depth_top (float | None | str | Unset):
+        depth_base (float | None | str | Unset):
+        stopcode (int | None | Unset):
     """
 
-    method_id: Union[None, UUID, Unset] = UNSET
-    name: Union[Unset, str] = "DP"
-    remarks: Union[None, Unset, str] = UNSET
-    method_status_id: Union[Unset, MethodStatusEnum] = UNSET
-    created_at: Union[None, Unset, datetime.datetime] = UNSET
-    created_by: Union[None, Unset, str] = UNSET
-    updated_at: Union[None, Unset, datetime.datetime] = UNSET
-    updated_by: Union[None, Unset, str] = UNSET
-    conducted_by: Union[None, Unset, str] = UNSET
-    conducted_at: Union[None, Unset, datetime.datetime] = UNSET
-    method_type_id: Union[Literal[25], Unset] = 25
-    type_: Union[Unset, DPType] = UNSET
-    predrilling_depth: Union[None, Unset, float, str] = UNSET
-    cone_type: Union[None, Unset, str] = UNSET
-    cushion_type: Union[None, Unset, str] = UNSET
-    use_damper: Union[None, Unset, bool] = UNSET
-    depth_top: Union[None, Unset, float, str] = UNSET
-    depth_base: Union[None, Unset, float, str] = UNSET
-    stopcode: Union[None, Unset, int] = UNSET
+    method_id: None | Unset | UUID = UNSET
+    name: str | Unset = "DP"
+    remarks: None | str | Unset = UNSET
+    method_status_id: MethodStatusEnum | Unset = UNSET
+    created_at: datetime.datetime | None | Unset = UNSET
+    created_by: None | str | Unset = UNSET
+    updated_at: datetime.datetime | None | Unset = UNSET
+    updated_by: None | str | Unset = UNSET
+    conducted_by: None | str | Unset = UNSET
+    conducted_at: datetime.datetime | None | Unset = UNSET
+    method_type_id: Literal[25] | Unset = 25
+    dynamic_probing_type: DPType | None | Unset = UNSET
+    predrilling_depth: float | None | str | Unset = UNSET
+    cone_type: None | str | Unset = UNSET
+    cushion_type: None | str | Unset = UNSET
+    use_damper: bool | None | Unset = UNSET
+    depth_top: float | None | str | Unset = UNSET
+    depth_base: float | None | str | Unset = UNSET
+    stopcode: int | None | Unset = UNSET
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
-        method_id: Union[None, Unset, str]
+        method_id: None | str | Unset
         if isinstance(self.method_id, Unset):
             method_id = UNSET
         elif isinstance(self.method_id, UUID):
@@ -76,17 +79,17 @@ class MethodDPCreate:
 
         name = self.name
 
-        remarks: Union[None, Unset, str]
+        remarks: None | str | Unset
         if isinstance(self.remarks, Unset):
             remarks = UNSET
         else:
             remarks = self.remarks
 
-        method_status_id: Union[Unset, int] = UNSET
+        method_status_id: int | Unset = UNSET
         if not isinstance(self.method_status_id, Unset):
             method_status_id = self.method_status_id.value
 
-        created_at: Union[None, Unset, str]
+        created_at: None | str | Unset
         if isinstance(self.created_at, Unset):
             created_at = UNSET
         elif isinstance(self.created_at, datetime.datetime):
@@ -94,13 +97,13 @@ class MethodDPCreate:
         else:
             created_at = self.created_at
 
-        created_by: Union[None, Unset, str]
+        created_by: None | str | Unset
         if isinstance(self.created_by, Unset):
             created_by = UNSET
         else:
             created_by = self.created_by
 
-        updated_at: Union[None, Unset, str]
+        updated_at: None | str | Unset
         if isinstance(self.updated_at, Unset):
             updated_at = UNSET
         elif isinstance(self.updated_at, datetime.datetime):
@@ -108,19 +111,19 @@ class MethodDPCreate:
         else:
             updated_at = self.updated_at
 
-        updated_by: Union[None, Unset, str]
+        updated_by: None | str | Unset
         if isinstance(self.updated_by, Unset):
             updated_by = UNSET
         else:
             updated_by = self.updated_by
 
-        conducted_by: Union[None, Unset, str]
+        conducted_by: None | str | Unset
         if isinstance(self.conducted_by, Unset):
             conducted_by = UNSET
         else:
             conducted_by = self.conducted_by
 
-        conducted_at: Union[None, Unset, str]
+        conducted_at: None | str | Unset
         if isinstance(self.conducted_at, Unset):
             conducted_at = UNSET
         elif isinstance(self.conducted_at, datetime.datetime):
@@ -130,47 +133,51 @@ class MethodDPCreate:
 
         method_type_id = self.method_type_id
 
-        type_: Union[Unset, str] = UNSET
-        if not isinstance(self.type_, Unset):
-            type_ = self.type_.value
+        dynamic_probing_type: None | str | Unset
+        if isinstance(self.dynamic_probing_type, Unset):
+            dynamic_probing_type = UNSET
+        elif isinstance(self.dynamic_probing_type, DPType):
+            dynamic_probing_type = self.dynamic_probing_type.value
+        else:
+            dynamic_probing_type = self.dynamic_probing_type
 
-        predrilling_depth: Union[None, Unset, float, str]
+        predrilling_depth: float | None | str | Unset
         if isinstance(self.predrilling_depth, Unset):
             predrilling_depth = UNSET
         else:
             predrilling_depth = self.predrilling_depth
 
-        cone_type: Union[None, Unset, str]
+        cone_type: None | str | Unset
         if isinstance(self.cone_type, Unset):
             cone_type = UNSET
         else:
             cone_type = self.cone_type
 
-        cushion_type: Union[None, Unset, str]
+        cushion_type: None | str | Unset
         if isinstance(self.cushion_type, Unset):
             cushion_type = UNSET
         else:
             cushion_type = self.cushion_type
 
-        use_damper: Union[None, Unset, bool]
+        use_damper: bool | None | Unset
         if isinstance(self.use_damper, Unset):
             use_damper = UNSET
         else:
             use_damper = self.use_damper
 
-        depth_top: Union[None, Unset, float, str]
+        depth_top: float | None | str | Unset
         if isinstance(self.depth_top, Unset):
             depth_top = UNSET
         else:
             depth_top = self.depth_top
 
-        depth_base: Union[None, Unset, float, str]
+        depth_base: float | None | str | Unset
         if isinstance(self.depth_base, Unset):
             depth_base = UNSET
         else:
             depth_base = self.depth_base
 
-        stopcode: Union[None, Unset, int]
+        stopcode: int | None | Unset
         if isinstance(self.stopcode, Unset):
             stopcode = UNSET
         else:
@@ -201,8 +208,8 @@ class MethodDPCreate:
             field_dict["conducted_at"] = conducted_at
         if method_type_id is not UNSET:
             field_dict["method_type_id"] = method_type_id
-        if type_ is not UNSET:
-            field_dict["type"] = type_
+        if dynamic_probing_type is not UNSET:
+            field_dict["dynamic_probing_type"] = dynamic_probing_type
         if predrilling_depth is not UNSET:
             field_dict["predrilling_depth"] = predrilling_depth
         if cone_type is not UNSET:
@@ -221,10 +228,10 @@ class MethodDPCreate:
         return field_dict
 
     @classmethod
-    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
-        d = src_dict.copy()
+    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
+        d = dict(src_dict)
 
-        def _parse_method_id(data: object) -> Union[None, UUID, Unset]:
+        def _parse_method_id(data: object) -> None | Unset | UUID:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -237,29 +244,29 @@ class MethodDPCreate:
                 return method_id_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, UUID, Unset], data)
+            return cast(None | Unset | UUID, data)
 
         method_id = _parse_method_id(d.pop("method_id", UNSET))
 
         name = d.pop("name", UNSET)
 
-        def _parse_remarks(data: object) -> Union[None, Unset, str]:
+        def _parse_remarks(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         remarks = _parse_remarks(d.pop("remarks", UNSET))
 
         _method_status_id = d.pop("method_status_id", UNSET)
-        method_status_id: Union[Unset, MethodStatusEnum]
+        method_status_id: MethodStatusEnum | Unset
         if isinstance(_method_status_id, Unset):
             method_status_id = UNSET
         else:
             method_status_id = MethodStatusEnum(_method_status_id)
 
-        def _parse_created_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_created_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -272,20 +279,20 @@ class MethodDPCreate:
                 return created_at_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         created_at = _parse_created_at(d.pop("created_at", UNSET))
 
-        def _parse_created_by(data: object) -> Union[None, Unset, str]:
+        def _parse_created_by(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         created_by = _parse_created_by(d.pop("created_by", UNSET))
 
-        def _parse_updated_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_updated_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -298,29 +305,29 @@ class MethodDPCreate:
                 return updated_at_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         updated_at = _parse_updated_at(d.pop("updated_at", UNSET))
 
-        def _parse_updated_by(data: object) -> Union[None, Unset, str]:
+        def _parse_updated_by(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         updated_by = _parse_updated_by(d.pop("updated_by", UNSET))
 
-        def _parse_conducted_by(data: object) -> Union[None, Unset, str]:
+        def _parse_conducted_by(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         conducted_by = _parse_conducted_by(d.pop("conducted_by", UNSET))
 
-        def _parse_conducted_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_conducted_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -333,81 +340,91 @@ class MethodDPCreate:
                 return conducted_at_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         conducted_at = _parse_conducted_at(d.pop("conducted_at", UNSET))
 
-        method_type_id = cast(Union[Literal[25], Unset], d.pop("method_type_id", UNSET))
+        method_type_id = cast(Literal[25] | Unset, d.pop("method_type_id", UNSET))
         if method_type_id != 25 and not isinstance(method_type_id, Unset):
             raise ValueError(f"method_type_id must match const 25, got '{method_type_id}'")
 
-        _type_ = d.pop("type", UNSET)
-        type_: Union[Unset, DPType]
-        if isinstance(_type_, Unset):
-            type_ = UNSET
-        else:
-            type_ = DPType(_type_)
-
-        def _parse_predrilling_depth(data: object) -> Union[None, Unset, float, str]:
+        def _parse_dynamic_probing_type(data: object) -> DPType | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            try:
+                if not isinstance(data, str):
+                    raise TypeError()
+                dynamic_probing_type_type_0 = DPType(data)
+
+                return dynamic_probing_type_type_0
+            except:  # noqa: E722
+                pass
+            return cast(DPType | None | Unset, data)
+
+        dynamic_probing_type = _parse_dynamic_probing_type(d.pop("dynamic_probing_type", UNSET))
+
+        def _parse_predrilling_depth(data: object) -> float | None | str | Unset:
+            if data is None:
+                return data
+            if isinstance(data, Unset):
+                return data
+            return cast(float | None | str | Unset, data)
 
         predrilling_depth = _parse_predrilling_depth(d.pop("predrilling_depth", UNSET))
 
-        def _parse_cone_type(data: object) -> Union[None, Unset, str]:
+        def _parse_cone_type(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         cone_type = _parse_cone_type(d.pop("cone_type", UNSET))
 
-        def _parse_cushion_type(data: object) -> Union[None, Unset, str]:
+        def _parse_cushion_type(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         cushion_type = _parse_cushion_type(d.pop("cushion_type", UNSET))
 
-        def _parse_use_damper(data: object) -> Union[None, Unset, bool]:
+        def _parse_use_damper(data: object) -> bool | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, bool], data)
+            return cast(bool | None | Unset, data)
 
         use_damper = _parse_use_damper(d.pop("use_damper", UNSET))
 
-        def _parse_depth_top(data: object) -> Union[None, Unset, float, str]:
+        def _parse_depth_top(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         depth_top = _parse_depth_top(d.pop("depth_top", UNSET))
 
-        def _parse_depth_base(data: object) -> Union[None, Unset, float, str]:
+        def _parse_depth_base(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         depth_base = _parse_depth_base(d.pop("depth_base", UNSET))
 
-        def _parse_stopcode(data: object) -> Union[None, Unset, int]:
+        def _parse_stopcode(data: object) -> int | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, int], data)
+            return cast(int | None | Unset, data)
 
         stopcode = _parse_stopcode(d.pop("stopcode", UNSET))
 
@@ -423,7 +440,7 @@ class MethodDPCreate:
             conducted_by=conducted_by,
             conducted_at=conducted_at,
             method_type_id=method_type_id,
-            type_=type_,
+            dynamic_probing_type=dynamic_probing_type,
             predrilling_depth=predrilling_depth,
             cone_type=cone_type,
             cushion_type=cushion_type,
