@@ -1,6 +1,8 @@
+from __future__ import annotations
+
 import datetime
 from collections.abc import Mapping
-from typing import TYPE_CHECKING, Any, Literal, TypeVar, Union, cast
+from typing import TYPE_CHECKING, Any, Literal, TypeVar, cast
 from uuid import UUID
 
 from attrs import define as _attrs_define
@@ -44,35 +46,34 @@ class MethodPZ:
         transformation_type (TransformationType): Piezometer Transformation Types
         mandatory_barometric_pressure (bool):
         mandatory_temperature (bool):
-        remarks (Union[None, Unset, str]):
-        method_type_id (Union[Literal[5], Unset]):  Default: 5.
-        created_by (Union[None, Unset, str]):
-        updated_by (Union[None, Unset, str]):
-        conducted_at (Union[None, Unset, datetime.datetime]):
-        conducted_by (Union[None, Unset, str]):
-        files (Union[Unset, list['File']]):
-        self_ (Union[None, Unset, str]):
-        depth_top (Union[None, Unset, float]):
-        depth_base (Union[None, Unset, float]):
-        distance_over_terrain (Union[None, Unset, float]):
-        model_id (Union[None, UUID, Unset]):
-        pore_pressure_unit (Union[None, Unset, str]):
-        serial_number (Union[None, Unset, str]):
-        default_barometric_pressure (Union[None, Unset, float]):
-        polynomial_factor_a (Union[None, Unset, float]):
-        polynomial_factor_b (Union[None, Unset, float]):
-        polynomial_factor_k (Union[None, Unset, float]):
-        polynomial_factor_a_unit (Union[None, Unset, str]):
-        polynomial_factor_b_unit (Union[None, Unset, str]):
-        polynomial_factor_k_unit (Union[None, Unset, str]):
-        zero_reading_pore_pressure (Union[None, Unset, float]):
-        zero_reading_barometric_pressure (Union[None, Unset, float]):
-        zero_reading_temperature (Union[None, Unset, float]):
-        missing_variables_pore_pressure (Union[None, Unset, list[str]]): Missing variables to calculate pore pressure.
-        missing_variables_piezometric_head (Union[None, Unset, list[str]]): Missing variables to calculate piezometric
-            head.
-        missing_variables_piezometric_potential (Union[None, Unset, list[str]]): Missing variables to calculate
-            piezometric potential.
+        remarks (None | str | Unset):
+        method_type_id (Literal[5] | Unset):  Default: 5.
+        created_by (None | str | Unset):
+        updated_by (None | str | Unset):
+        conducted_at (datetime.datetime | None | Unset):
+        conducted_by (None | str | Unset):
+        files (list[File] | Unset):
+        self_ (None | str | Unset):
+        depth_top (float | None | Unset):
+        depth_base (float | None | Unset):
+        distance_over_terrain (float | None | Unset):
+        model_id (None | Unset | UUID):
+        pore_pressure_unit (None | str | Unset):
+        serial_number (None | str | Unset):
+        default_barometric_pressure (float | None | Unset):
+        polynomial_factor_a (float | None | Unset):
+        polynomial_factor_b (float | None | Unset):
+        polynomial_factor_k (float | None | Unset):
+        polynomial_factor_a_unit (None | str | Unset):
+        polynomial_factor_b_unit (None | str | Unset):
+        polynomial_factor_k_unit (None | str | Unset):
+        zero_reading_pore_pressure (float | None | Unset):
+        zero_reading_barometric_pressure (float | None | Unset):
+        zero_reading_temperature (float | None | Unset):
+        missing_variables_pore_pressure (list[str] | None | Unset): Missing variables to calculate pore pressure.
+        missing_variables_piezometric_head (list[str] | None | Unset): Missing variables to calculate piezometric head.
+        missing_variables_piezometric_potential (list[str] | None | Unset): Missing variables to calculate piezometric
+            potential.
     """
 
     method_id: UUID
@@ -85,33 +86,33 @@ class MethodPZ:
     transformation_type: TransformationType
     mandatory_barometric_pressure: bool
     mandatory_temperature: bool
-    remarks: Union[None, Unset, str] = UNSET
-    method_type_id: Union[Literal[5], Unset] = 5
-    created_by: Union[None, Unset, str] = UNSET
-    updated_by: Union[None, Unset, str] = UNSET
-    conducted_at: Union[None, Unset, datetime.datetime] = UNSET
-    conducted_by: Union[None, Unset, str] = UNSET
-    files: Union[Unset, list["File"]] = UNSET
-    self_: Union[None, Unset, str] = UNSET
-    depth_top: Union[None, Unset, float] = UNSET
-    depth_base: Union[None, Unset, float] = UNSET
-    distance_over_terrain: Union[None, Unset, float] = UNSET
-    model_id: Union[None, UUID, Unset] = UNSET
-    pore_pressure_unit: Union[None, Unset, str] = UNSET
-    serial_number: Union[None, Unset, str] = UNSET
-    default_barometric_pressure: Union[None, Unset, float] = UNSET
-    polynomial_factor_a: Union[None, Unset, float] = UNSET
-    polynomial_factor_b: Union[None, Unset, float] = UNSET
-    polynomial_factor_k: Union[None, Unset, float] = UNSET
-    polynomial_factor_a_unit: Union[None, Unset, str] = UNSET
-    polynomial_factor_b_unit: Union[None, Unset, str] = UNSET
-    polynomial_factor_k_unit: Union[None, Unset, str] = UNSET
-    zero_reading_pore_pressure: Union[None, Unset, float] = UNSET
-    zero_reading_barometric_pressure: Union[None, Unset, float] = UNSET
-    zero_reading_temperature: Union[None, Unset, float] = UNSET
-    missing_variables_pore_pressure: Union[None, Unset, list[str]] = UNSET
-    missing_variables_piezometric_head: Union[None, Unset, list[str]] = UNSET
-    missing_variables_piezometric_potential: Union[None, Unset, list[str]] = UNSET
+    remarks: None | str | Unset = UNSET
+    method_type_id: Literal[5] | Unset = 5
+    created_by: None | str | Unset = UNSET
+    updated_by: None | str | Unset = UNSET
+    conducted_at: datetime.datetime | None | Unset = UNSET
+    conducted_by: None | str | Unset = UNSET
+    files: list[File] | Unset = UNSET
+    self_: None | str | Unset = UNSET
+    depth_top: float | None | Unset = UNSET
+    depth_base: float | None | Unset = UNSET
+    distance_over_terrain: float | None | Unset = UNSET
+    model_id: None | Unset | UUID = UNSET
+    pore_pressure_unit: None | str | Unset = UNSET
+    serial_number: None | str | Unset = UNSET
+    default_barometric_pressure: float | None | Unset = UNSET
+    polynomial_factor_a: float | None | Unset = UNSET
+    polynomial_factor_b: float | None | Unset = UNSET
+    polynomial_factor_k: float | None | Unset = UNSET
+    polynomial_factor_a_unit: None | str | Unset = UNSET
+    polynomial_factor_b_unit: None | str | Unset = UNSET
+    polynomial_factor_k_unit: None | str | Unset = UNSET
+    zero_reading_pore_pressure: float | None | Unset = UNSET
+    zero_reading_barometric_pressure: float | None | Unset = UNSET
+    zero_reading_temperature: float | None | Unset = UNSET
+    missing_variables_pore_pressure: list[str] | None | Unset = UNSET
+    missing_variables_piezometric_head: list[str] | None | Unset = UNSET
+    missing_variables_piezometric_potential: list[str] | None | Unset = UNSET
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
@@ -135,7 +136,7 @@ class MethodPZ:
 
         mandatory_temperature = self.mandatory_temperature
 
-        remarks: Union[None, Unset, str]
+        remarks: None | str | Unset
         if isinstance(self.remarks, Unset):
             remarks = UNSET
         else:
@@ -143,19 +144,19 @@ class MethodPZ:
 
         method_type_id = self.method_type_id
 
-        created_by: Union[None, Unset, str]
+        created_by: None | str | Unset
         if isinstance(self.created_by, Unset):
             created_by = UNSET
         else:
             created_by = self.created_by
 
-        updated_by: Union[None, Unset, str]
+        updated_by: None | str | Unset
         if isinstance(self.updated_by, Unset):
             updated_by = UNSET
         else:
             updated_by = self.updated_by
 
-        conducted_at: Union[None, Unset, str]
+        conducted_at: None | str | Unset
         if isinstance(self.conducted_at, Unset):
             conducted_at = UNSET
         elif isinstance(self.conducted_at, datetime.datetime):
@@ -163,44 +164,44 @@ class MethodPZ:
         else:
             conducted_at = self.conducted_at
 
-        conducted_by: Union[None, Unset, str]
+        conducted_by: None | str | Unset
         if isinstance(self.conducted_by, Unset):
             conducted_by = UNSET
         else:
             conducted_by = self.conducted_by
 
-        files: Union[Unset, list[dict[str, Any]]] = UNSET
+        files: list[dict[str, Any]] | Unset = UNSET
         if not isinstance(self.files, Unset):
             files = []
             for files_item_data in self.files:
                 files_item = files_item_data.to_dict()
                 files.append(files_item)
 
-        self_: Union[None, Unset, str]
+        self_: None | str | Unset
         if isinstance(self.self_, Unset):
             self_ = UNSET
         else:
             self_ = self.self_
 
-        depth_top: Union[None, Unset, float]
+        depth_top: float | None | Unset
         if isinstance(self.depth_top, Unset):
             depth_top = UNSET
         else:
             depth_top = self.depth_top
 
-        depth_base: Union[None, Unset, float]
+        depth_base: float | None | Unset
         if isinstance(self.depth_base, Unset):
             depth_base = UNSET
         else:
             depth_base = self.depth_base
 
-        distance_over_terrain: Union[None, Unset, float]
+        distance_over_terrain: float | None | Unset
         if isinstance(self.distance_over_terrain, Unset):
             distance_over_terrain = UNSET
         else:
             distance_over_terrain = self.distance_over_terrain
 
-        model_id: Union[None, Unset, str]
+        model_id: None | str | Unset
         if isinstance(self.model_id, Unset):
             model_id = UNSET
         elif isinstance(self.model_id, UUID):
@@ -208,79 +209,79 @@ class MethodPZ:
         else:
             model_id = self.model_id
 
-        pore_pressure_unit: Union[None, Unset, str]
+        pore_pressure_unit: None | str | Unset
         if isinstance(self.pore_pressure_unit, Unset):
             pore_pressure_unit = UNSET
         else:
             pore_pressure_unit = self.pore_pressure_unit
 
-        serial_number: Union[None, Unset, str]
+        serial_number: None | str | Unset
         if isinstance(self.serial_number, Unset):
             serial_number = UNSET
         else:
             serial_number = self.serial_number
 
-        default_barometric_pressure: Union[None, Unset, float]
+        default_barometric_pressure: float | None | Unset
         if isinstance(self.default_barometric_pressure, Unset):
             default_barometric_pressure = UNSET
         else:
             default_barometric_pressure = self.default_barometric_pressure
 
-        polynomial_factor_a: Union[None, Unset, float]
+        polynomial_factor_a: float | None | Unset
         if isinstance(self.polynomial_factor_a, Unset):
             polynomial_factor_a = UNSET
         else:
             polynomial_factor_a = self.polynomial_factor_a
 
-        polynomial_factor_b: Union[None, Unset, float]
+        polynomial_factor_b: float | None | Unset
         if isinstance(self.polynomial_factor_b, Unset):
             polynomial_factor_b = UNSET
         else:
             polynomial_factor_b = self.polynomial_factor_b
 
-        polynomial_factor_k: Union[None, Unset, float]
+        polynomial_factor_k: float | None | Unset
         if isinstance(self.polynomial_factor_k, Unset):
             polynomial_factor_k = UNSET
         else:
             polynomial_factor_k = self.polynomial_factor_k
 
-        polynomial_factor_a_unit: Union[None, Unset, str]
+        polynomial_factor_a_unit: None | str | Unset
         if isinstance(self.polynomial_factor_a_unit, Unset):
             polynomial_factor_a_unit = UNSET
         else:
             polynomial_factor_a_unit = self.polynomial_factor_a_unit
 
-        polynomial_factor_b_unit: Union[None, Unset, str]
+        polynomial_factor_b_unit: None | str | Unset
         if isinstance(self.polynomial_factor_b_unit, Unset):
             polynomial_factor_b_unit = UNSET
         else:
             polynomial_factor_b_unit = self.polynomial_factor_b_unit
 
-        polynomial_factor_k_unit: Union[None, Unset, str]
+        polynomial_factor_k_unit: None | str | Unset
         if isinstance(self.polynomial_factor_k_unit, Unset):
             polynomial_factor_k_unit = UNSET
         else:
             polynomial_factor_k_unit = self.polynomial_factor_k_unit
 
-        zero_reading_pore_pressure: Union[None, Unset, float]
+        zero_reading_pore_pressure: float | None | Unset
         if isinstance(self.zero_reading_pore_pressure, Unset):
             zero_reading_pore_pressure = UNSET
         else:
             zero_reading_pore_pressure = self.zero_reading_pore_pressure
 
-        zero_reading_barometric_pressure: Union[None, Unset, float]
+        zero_reading_barometric_pressure: float | None | Unset
         if isinstance(self.zero_reading_barometric_pressure, Unset):
             zero_reading_barometric_pressure = UNSET
         else:
             zero_reading_barometric_pressure = self.zero_reading_barometric_pressure
 
-        zero_reading_temperature: Union[None, Unset, float]
+        zero_reading_temperature: float | None | Unset
         if isinstance(self.zero_reading_temperature, Unset):
             zero_reading_temperature = UNSET
         else:
             zero_reading_temperature = self.zero_reading_temperature
 
-        missing_variables_pore_pressure: Union[None, Unset, list[str]]
+        missing_variables_pore_pressure: list[str] | None | Unset
         if isinstance(self.missing_variables_pore_pressure, Unset):
             missing_variables_pore_pressure = UNSET
         elif isinstance(self.missing_variables_pore_pressure, list):
@@ -289,7 +290,7 @@ class MethodPZ:
         else:
             missing_variables_pore_pressure = self.missing_variables_pore_pressure
 
-        missing_variables_piezometric_head: Union[None, Unset, list[str]]
+        missing_variables_piezometric_head: list[str] | None | Unset
         if isinstance(self.missing_variables_piezometric_head, Unset):
             missing_variables_piezometric_head = UNSET
         elif isinstance(self.missing_variables_piezometric_head, list):
@@ -298,7 +299,7 @@ class MethodPZ:
         else:
             missing_variables_piezometric_head = self.missing_variables_piezometric_head
 
-        missing_variables_piezometric_potential: Union[None, Unset, list[str]]
+        missing_variables_piezometric_potential: list[str] | None | Unset
         if isinstance(self.missing_variables_piezometric_potential, Unset):
             missing_variables_piezometric_potential = UNSET
         elif isinstance(self.missing_variables_piezometric_potential, list):
@@ -405,38 +406,38 @@ class MethodPZ:
 
         mandatory_temperature = d.pop("mandatory_temperature")
 
-        def _parse_remarks(data: object) -> Union[None, Unset, str]:
+        def _parse_remarks(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         remarks = _parse_remarks(d.pop("remarks", UNSET))
 
-        method_type_id = cast(Union[Literal[5], Unset], d.pop("method_type_id", UNSET))
+        method_type_id = cast(Literal[5] | Unset, d.pop("method_type_id", UNSET))
         if method_type_id != 5 and not isinstance(method_type_id, Unset):
             raise ValueError(f"method_type_id must match const 5, got '{method_type_id}'")
 
-        def _parse_created_by(data: object) -> Union[None, Unset, str]:
+        def _parse_created_by(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         created_by = _parse_created_by(d.pop("created_by", UNSET))
 
-        def _parse_updated_by(data: object) -> Union[None, Unset, str]:
+        def _parse_updated_by(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         updated_by = _parse_updated_by(d.pop("updated_by", UNSET))
 
-        def _parse_conducted_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_conducted_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -449,16 +450,16 @@ class MethodPZ:
                 return conducted_at_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         conducted_at = _parse_conducted_at(d.pop("conducted_at", UNSET))
 
-        def _parse_conducted_by(data: object) -> Union[None, Unset, str]:
+        def _parse_conducted_by(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         conducted_by = _parse_conducted_by(d.pop("conducted_by", UNSET))
 
@@ -469,43 +470,43 @@ class MethodPZ:
 
             files.append(files_item)
 
-        def _parse_self_(data: object) -> Union[None, Unset, str]:
+        def _parse_self_(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         self_ = _parse_self_(d.pop("self", UNSET))
 
-        def _parse_depth_top(data: object) -> Union[None, Unset, float]:
+        def _parse_depth_top(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         depth_top = _parse_depth_top(d.pop("depth_top", UNSET))
 
-        def _parse_depth_base(data: object) -> Union[None, Unset, float]:
+        def _parse_depth_base(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         depth_base = _parse_depth_base(d.pop("depth_base", UNSET))
 
-        def _parse_distance_over_terrain(data: object) -> Union[None, Unset, float]:
+        def _parse_distance_over_terrain(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         distance_over_terrain = _parse_distance_over_terrain(d.pop("distance_over_terrain", UNSET))
 
-        def _parse_model_id(data: object) -> Union[None, UUID, Unset]:
+        def _parse_model_id(data: object) -> None | Unset | UUID:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -518,121 +519,121 @@ class MethodPZ:
                 return model_id_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, UUID, Unset], data)
+            return cast(None | Unset | UUID, data)
 
         model_id = _parse_model_id(d.pop("model_id", UNSET))
 
-        def _parse_pore_pressure_unit(data: object) -> Union[None, Unset, str]:
+        def _parse_pore_pressure_unit(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         pore_pressure_unit = _parse_pore_pressure_unit(d.pop("pore_pressure_unit", UNSET))
 
-        def _parse_serial_number(data: object) -> Union[None, Unset, str]:
+        def _parse_serial_number(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         serial_number = _parse_serial_number(d.pop("serial_number", UNSET))
 
-        def _parse_default_barometric_pressure(data: object) -> Union[None, Unset, float]:
+        def _parse_default_barometric_pressure(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         default_barometric_pressure = _parse_default_barometric_pressure(d.pop("default_barometric_pressure", UNSET))
 
-        def _parse_polynomial_factor_a(data: object) -> Union[None, Unset, float]:
+        def _parse_polynomial_factor_a(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         polynomial_factor_a = _parse_polynomial_factor_a(d.pop("polynomial_factor_a", UNSET))
 
-        def _parse_polynomial_factor_b(data: object) -> Union[None, Unset, float]:
+        def _parse_polynomial_factor_b(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         polynomial_factor_b = _parse_polynomial_factor_b(d.pop("polynomial_factor_b", UNSET))
 
-        def _parse_polynomial_factor_k(data: object) -> Union[None, Unset, float]:
+        def _parse_polynomial_factor_k(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         polynomial_factor_k = _parse_polynomial_factor_k(d.pop("polynomial_factor_k", UNSET))
 
-        def _parse_polynomial_factor_a_unit(data: object) -> Union[None, Unset, str]:
+        def _parse_polynomial_factor_a_unit(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         polynomial_factor_a_unit = _parse_polynomial_factor_a_unit(d.pop("polynomial_factor_a_unit", UNSET))
 
-        def _parse_polynomial_factor_b_unit(data: object) -> Union[None, Unset, str]:
+        def _parse_polynomial_factor_b_unit(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         polynomial_factor_b_unit = _parse_polynomial_factor_b_unit(d.pop("polynomial_factor_b_unit", UNSET))
 
-        def _parse_polynomial_factor_k_unit(data: object) -> Union[None, Unset, str]:
+        def _parse_polynomial_factor_k_unit(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         polynomial_factor_k_unit = _parse_polynomial_factor_k_unit(d.pop("polynomial_factor_k_unit", UNSET))
 
-        def _parse_zero_reading_pore_pressure(data: object) -> Union[None, Unset, float]:
+        def _parse_zero_reading_pore_pressure(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         zero_reading_pore_pressure = _parse_zero_reading_pore_pressure(d.pop("zero_reading_pore_pressure", UNSET))
 
-        def _parse_zero_reading_barometric_pressure(data: object) -> Union[None, Unset, float]:
+        def _parse_zero_reading_barometric_pressure(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         zero_reading_barometric_pressure = _parse_zero_reading_barometric_pressure(
             d.pop("zero_reading_barometric_pressure", UNSET)
         )
 
-        def _parse_zero_reading_temperature(data: object) -> Union[None, Unset, float]:
+        def _parse_zero_reading_temperature(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         zero_reading_temperature = _parse_zero_reading_temperature(d.pop("zero_reading_temperature", UNSET))
 
-        def _parse_missing_variables_pore_pressure(data: object) -> Union[None, Unset, list[str]]:
+        def _parse_missing_variables_pore_pressure(data: object) -> list[str] | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -645,13 +646,13 @@ class MethodPZ:
                 return missing_variables_pore_pressure_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, Unset, list[str]], data)
+            return cast(list[str] | None | Unset, data)
 
         missing_variables_pore_pressure = _parse_missing_variables_pore_pressure(
             d.pop("missing_variables_pore_pressure", UNSET)
         )
 
-        def _parse_missing_variables_piezometric_head(data: object) -> Union[None, Unset, list[str]]:
+        def _parse_missing_variables_piezometric_head(data: object) -> list[str] | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -664,13 +665,13 @@ class MethodPZ:
                 return missing_variables_piezometric_head_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, Unset, list[str]], data)
+            return cast(list[str] | None | Unset, data)
 
         missing_variables_piezometric_head = _parse_missing_variables_piezometric_head(
             d.pop("missing_variables_piezometric_head", UNSET)
         )
 
-        def _parse_missing_variables_piezometric_potential(data: object) -> Union[None, Unset, list[str]]:
+        def _parse_missing_variables_piezometric_potential(data: object) -> list[str] | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -683,7 +684,7 @@ class MethodPZ:
                 return missing_variables_piezometric_potential_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, Unset, list[str]], data)
+            return cast(list[str] | None | Unset, data)
 
         missing_variables_piezometric_potential = _parse_missing_variables_piezometric_potential(
             d.pop("missing_variables_piezometric_potential", UNSET)
