@@ -1,5 +1,8 @@
+from __future__ import annotations
+
 import datetime
-from typing import Any, Literal, TypeVar, Union, cast
+from collections.abc import Mapping
+from typing import Any, Literal, TypeVar, cast
 from uuid import UUID
 
 from attrs import define as _attrs_define
@@ -16,56 +19,56 @@ T = TypeVar("T", bound="MethodSACreate")
 class MethodSACreate:
     """
     Attributes:
-        method_id (Union[None, UUID, Unset]):
-        name (Union[Unset, str]):  Default: 'SA'.
-        remarks (Union[None, Unset, str]):
-        method_status_id (Union[Unset, MethodStatusEnum]): (
+        method_id (None | Unset | UUID):
+        name (str | Unset):  Default: 'SA'.
+        remarks (None | str | Unset):
+        method_status_id (MethodStatusEnum | Unset): (
             PLANNED=1,
             READY=2,
             CONDUCTED=3,
             VOIDED=4,
             APPROVED=5,
             )
-        created_at (Union[None, Unset, datetime.datetime]):
-        created_by (Union[None, Unset, str]):
-        updated_at (Union[None, Unset, datetime.datetime]):
-        updated_by (Union[None, Unset, str]):
-        conducted_by (Union[None, Unset, str]):
-        conducted_at (Union[None, Unset, datetime.datetime]):
-        method_type_id (Union[Literal[4], Unset]):  Default: 4.
-        depth_top (Union[None, Unset, float, str]):
-        depth_base (Union[None, Unset, float, str]):
-        diameter (Union[None, Unset, float, str]):
-        sample_container_id (Union[None, Unset, str]):
-        sample_container_type_id (Union[None, Unset, int]):
-        sample_material_ids (Union[Unset, list[int]]):
-        ags_sample_type (Union[None, Unset, str]):
-        sampling_technique_id (Union[None, Unset, int]):
+        created_at (datetime.datetime | None | Unset):
+        created_by (None | str | Unset):
+        updated_at (datetime.datetime | None | Unset):
+        updated_by (None | str | Unset):
+        conducted_by (None | str | Unset):
+        conducted_at (datetime.datetime | None | Unset):
+        method_type_id (Literal[4] | Unset):  Default: 4.
+        depth_top (float | None | str | Unset):
+        depth_base (float | None | str | Unset):
+        diameter (float | None | str | Unset):
+        sample_container_id (None | str | Unset):
+        sample_container_type_id (int | None | Unset):
+        sample_material_ids (list[int] | Unset):
+        ags_sample_type (None | str | Unset):
+        sampling_technique_id (int | None | Unset):
     """
 
-    method_id: Union[None, UUID, Unset] = UNSET
-    name: Union[Unset, str] = "SA"
-    remarks: Union[None, Unset, str] = UNSET
-    method_status_id: Union[Unset, MethodStatusEnum] = UNSET
-    created_at: Union[None, Unset, datetime.datetime] = UNSET
-    created_by: Union[None, Unset, str] = UNSET
-    updated_at: Union[None, Unset, datetime.datetime] = UNSET
-    updated_by: Union[None, Unset, str] = UNSET
-    conducted_by: Union[None, Unset, str] = UNSET
-    conducted_at: Union[None, Unset, datetime.datetime] = UNSET
-    method_type_id: Union[Literal[4], Unset] = 4
-    depth_top: Union[None, Unset, float, str] = UNSET
-    depth_base: Union[None, Unset, float, str] = UNSET
-    diameter: Union[None, Unset, float, str] = UNSET
-    sample_container_id: Union[None, Unset, str] = UNSET
-    sample_container_type_id: Union[None, Unset, int] = UNSET
-    sample_material_ids: Union[Unset, list[int]] = UNSET
-    ags_sample_type: Union[None, Unset, str] = UNSET
-    sampling_technique_id: Union[None, Unset, int] = UNSET
+    method_id: None | Unset | UUID = UNSET
+    name: str | Unset = "SA"
+    remarks: None | str | Unset = UNSET
+    method_status_id: MethodStatusEnum | Unset = UNSET
+    created_at: datetime.datetime | None | Unset = UNSET
+    created_by: None | str | Unset = UNSET
+    updated_at: datetime.datetime | None | Unset = UNSET
+    updated_by: None | str | Unset = UNSET
+    conducted_by: None | str | Unset = UNSET
+    conducted_at: datetime.datetime | None | Unset = UNSET
+    method_type_id: Literal[4] | Unset = 4
+    depth_top: float | None | str | Unset = UNSET
+    depth_base: float | None | str | Unset = UNSET
+    diameter: float | None | str | Unset = UNSET
+    sample_container_id: None | str | Unset = UNSET
+    sample_container_type_id: int | None | Unset = UNSET
+    sample_material_ids: list[int] | Unset = UNSET
+    ags_sample_type: None | str | Unset = UNSET
+    sampling_technique_id: int | None | Unset = UNSET
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
-        method_id: Union[None, Unset, str]
+        method_id: None | str | Unset
         if isinstance(self.method_id, Unset):
             method_id = UNSET
         elif isinstance(self.method_id, UUID):
@@ -75,17 +78,17 @@ class MethodSACreate:
 
         name = self.name
 
-        remarks: Union[None, Unset, str]
+        remarks: None | str | Unset
         if isinstance(self.remarks, Unset):
             remarks = UNSET
         else:
             remarks = self.remarks
 
-        method_status_id: Union[Unset, int] = UNSET
+        method_status_id: int | Unset = UNSET
         if not isinstance(self.method_status_id, Unset):
             method_status_id = self.method_status_id.value
 
-        created_at: Union[None, Unset, str]
+        created_at: None | str | Unset
         if isinstance(self.created_at, Unset):
             created_at = UNSET
         elif isinstance(self.created_at, datetime.datetime):
@@ -93,13 +96,13 @@ class MethodSACreate:
         else:
             created_at = self.created_at
 
-        created_by: Union[None, Unset, str]
+        created_by: None | str | Unset
         if isinstance(self.created_by, Unset):
             created_by = UNSET
         else:
             created_by = self.created_by
 
-        updated_at: Union[None, Unset, str]
+        updated_at: None | str | Unset
         if isinstance(self.updated_at, Unset):
             updated_at = UNSET
         elif isinstance(self.updated_at, datetime.datetime):
@@ -107,19 +110,19 @@ class MethodSACreate:
         else:
             updated_at = self.updated_at
 
-        updated_by: Union[None, Unset, str]
+        updated_by: None | str | Unset
         if isinstance(self.updated_by, Unset):
             updated_by = UNSET
         else:
             updated_by = self.updated_by
 
-        conducted_by: Union[None, Unset, str]
+        conducted_by: None | str | Unset
         if isinstance(self.conducted_by, Unset):
             conducted_by = UNSET
         else:
             conducted_by = self.conducted_by
 
-        conducted_at: Union[None, Unset, str]
+        conducted_at: None | str | Unset
         if isinstance(self.conducted_at, Unset):
             conducted_at = UNSET
         elif isinstance(self.conducted_at, datetime.datetime):
@@ -129,47 +132,47 @@ class MethodSACreate:
 
         method_type_id = self.method_type_id
 
-        depth_top: Union[None, Unset, float, str]
+        depth_top: float | None | str | Unset
         if isinstance(self.depth_top, Unset):
             depth_top = UNSET
         else:
             depth_top = self.depth_top
 
-        depth_base: Union[None, Unset, float, str]
+        depth_base: float | None | str | Unset
         if isinstance(self.depth_base, Unset):
             depth_base = UNSET
         else:
             depth_base = self.depth_base
 
-        diameter: Union[None, Unset, float, str]
+        diameter: float | None | str | Unset
         if isinstance(self.diameter, Unset):
             diameter = UNSET
         else:
             diameter = self.diameter
 
-        sample_container_id: Union[None, Unset, str]
+        sample_container_id: None | str | Unset
         if isinstance(self.sample_container_id, Unset):
             sample_container_id = UNSET
         else:
             sample_container_id = self.sample_container_id
 
-        sample_container_type_id: Union[None, Unset, int]
+        sample_container_type_id: int | None | Unset
         if isinstance(self.sample_container_type_id, Unset):
             sample_container_type_id = UNSET
         else:
             sample_container_type_id = self.sample_container_type_id
 
-        sample_material_ids: Union[Unset, list[int]] = UNSET
+        sample_material_ids: list[int] | Unset = UNSET
         if not isinstance(self.sample_material_ids, Unset):
             sample_material_ids = self.sample_material_ids
 
-        ags_sample_type: Union[None, Unset, str]
+        ags_sample_type: None | str | Unset
         if isinstance(self.ags_sample_type, Unset):
             ags_sample_type = UNSET
         else:
             ags_sample_type = self.ags_sample_type
 
-        sampling_technique_id: Union[None, Unset, int]
+        sampling_technique_id: int | None | Unset
         if isinstance(self.sampling_technique_id, Unset):
             sampling_technique_id = UNSET
         else:
@@ -220,10 +223,10 @@ class MethodSACreate:
         return field_dict
 
     @classmethod
-    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
-        d = src_dict.copy()
+    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
+        d = dict(src_dict)
 
-        def _parse_method_id(data: object) -> Union[None, UUID, Unset]:
+        def _parse_method_id(data: object) -> None | Unset | UUID:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -236,29 +239,29 @@ class MethodSACreate:
                 return method_id_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, UUID, Unset], data)
+            return cast(None | Unset | UUID, data)
 
         method_id = _parse_method_id(d.pop("method_id", UNSET))
 
         name = d.pop("name", UNSET)
 
-        def _parse_remarks(data: object) -> Union[None, Unset, str]:
+        def _parse_remarks(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         remarks = _parse_remarks(d.pop("remarks", UNSET))
 
         _method_status_id = d.pop("method_status_id", UNSET)
-        method_status_id: Union[Unset, MethodStatusEnum]
+        method_status_id: MethodStatusEnum | Unset
         if isinstance(_method_status_id, Unset):
             method_status_id = UNSET
         else:
             method_status_id = MethodStatusEnum(_method_status_id)
 
-        def _parse_created_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_created_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -271,20 +274,20 @@ class MethodSACreate:
                 return created_at_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         created_at = _parse_created_at(d.pop("created_at", UNSET))
 
-        def _parse_created_by(data: object) -> Union[None, Unset, str]:
+        def _parse_created_by(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         created_by = _parse_created_by(d.pop("created_by", UNSET))
 
-        def _parse_updated_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_updated_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -297,29 +300,29 @@ class MethodSACreate:
                 return updated_at_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         updated_at = _parse_updated_at(d.pop("updated_at", UNSET))
 
-        def _parse_updated_by(data: object) -> Union[None, Unset, str]:
+        def _parse_updated_by(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         updated_by = _parse_updated_by(d.pop("updated_by", UNSET))
 
-        def _parse_conducted_by(data: object) -> Union[None, Unset, str]:
+        def _parse_conducted_by(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         conducted_by = _parse_conducted_by(d.pop("conducted_by", UNSET))
 
-        def _parse_conducted_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_conducted_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -332,76 +335,76 @@ class MethodSACreate:
                 return conducted_at_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         conducted_at = _parse_conducted_at(d.pop("conducted_at", UNSET))
 
-        method_type_id = cast(Union[Literal[4], Unset], d.pop("method_type_id", UNSET))
+        method_type_id = cast(Literal[4] | Unset, d.pop("method_type_id", UNSET))
         if method_type_id != 4 and not isinstance(method_type_id, Unset):
             raise ValueError(f"method_type_id must match const 4, got '{method_type_id}'")
 
-        def _parse_depth_top(data: object) -> Union[None, Unset, float, str]:
+        def _parse_depth_top(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         depth_top = _parse_depth_top(d.pop("depth_top", UNSET))
 
-        def _parse_depth_base(data: object) -> Union[None, Unset, float, str]:
+        def _parse_depth_base(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         depth_base = _parse_depth_base(d.pop("depth_base", UNSET))
 
-        def _parse_diameter(data: object) -> Union[None, Unset, float, str]:
+        def _parse_diameter(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         diameter = _parse_diameter(d.pop("diameter", UNSET))
 
-        def _parse_sample_container_id(data: object) -> Union[None, Unset, str]:
+        def _parse_sample_container_id(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         sample_container_id = _parse_sample_container_id(d.pop("sample_container_id", UNSET))
 
-        def _parse_sample_container_type_id(data: object) -> Union[None, Unset, int]:
+        def _parse_sample_container_type_id(data: object) -> int | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, int], data)
+            return cast(int | None | Unset, data)
 
         sample_container_type_id = _parse_sample_container_type_id(d.pop("sample_container_type_id", UNSET))
 
         sample_material_ids = cast(list[int], d.pop("sample_material_ids", UNSET))
 
-        def _parse_ags_sample_type(data: object) -> Union[None, Unset, str]:
+        def _parse_ags_sample_type(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         ags_sample_type = _parse_ags_sample_type(d.pop("ags_sample_type", UNSET))
 
-        def _parse_sampling_technique_id(data: object) -> Union[None, Unset, int]:
+        def _parse_sampling_technique_id(data: object) -> int | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, int], data)
+            return cast(int | None | Unset, data)
 
         sampling_technique_id = _parse_sampling_technique_id(d.pop("sampling_technique_id", UNSET))
 
