@@ -1,5 +1,8 @@
+from __future__ import annotations
+
 import datetime
-from typing import Any, Literal, TypeVar, Union, cast
+from collections.abc import Mapping
+from typing import Any, Literal, TypeVar, cast
 from uuid import UUID
 
 from attrs import define as _attrs_define
@@ -17,32 +20,32 @@ class MethodTOTUpdate:
     """Structure for updating a total sounding method instance
 
     Attributes:
-        method_id (Union[None, UUID, Unset]):
-        name (Union[None, Unset, str]):
-        remarks (Union[None, Unset, str]):
-        method_status_id (Union[MethodStatusEnum, None, Unset]):
-        updated_at (Union[None, Unset, datetime.datetime]):
-        updated_by (Union[None, Unset, str]):
-        conducted_by (Union[None, Unset, str]):
-        conducted_at (Union[None, Unset, datetime.datetime]):
-        method_type_id (Union[Literal[2], Unset]):  Default: 2.
-        predrilling_depth (Union[None, Unset, float, str]):
+        method_id (None | Unset | UUID):
+        name (None | str | Unset):
+        remarks (None | str | Unset):
+        method_status_id (MethodStatusEnum | None | Unset):
+        updated_at (datetime.datetime | None | Unset):
+        updated_by (None | str | Unset):
+        conducted_by (None | str | Unset):
+        conducted_at (datetime.datetime | None | Unset):
+        method_type_id (Literal[2] | Unset):  Default: 2.
+        predrilling_depth (float | None | str | Unset):
     """
 
-    method_id: Union[None, UUID, Unset] = UNSET
-    name: Union[None, Unset, str] = UNSET
-    remarks: Union[None, Unset, str] = UNSET
-    method_status_id: Union[MethodStatusEnum, None, Unset] = UNSET
-    updated_at: Union[None, Unset, datetime.datetime] = UNSET
-    updated_by: Union[None, Unset, str] = UNSET
-    conducted_by: Union[None, Unset, str] = UNSET
-    conducted_at: Union[None, Unset, datetime.datetime] = UNSET
-    method_type_id: Union[Literal[2], Unset] = 2
-    predrilling_depth: Union[None, Unset, float, str] = UNSET
+    method_id: None | Unset | UUID = UNSET
+    name: None | str | Unset = UNSET
+    remarks: None | str | Unset = UNSET
+    method_status_id: MethodStatusEnum | None | Unset = UNSET
+    updated_at: datetime.datetime | None | Unset = UNSET
+    updated_by: None | str | Unset = UNSET
+    conducted_by: None | str | Unset = UNSET
+    conducted_at: datetime.datetime | None | Unset = UNSET
+    method_type_id: Literal[2] | Unset = 2
+    predrilling_depth: float | None | str | Unset = UNSET
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
-        method_id: Union[None, Unset, str]
+        method_id: None | str | Unset
         if isinstance(self.method_id, Unset):
             method_id = UNSET
         elif isinstance(self.method_id, UUID):
@@ -50,19 +53,19 @@ class MethodTOTUpdate:
         else:
             method_id = self.method_id
 
-        name: Union[None, Unset, str]
+        name: None | str | Unset
         if isinstance(self.name, Unset):
             name = UNSET
         else:
             name = self.name
 
-        remarks: Union[None, Unset, str]
+        remarks: None | str | Unset
         if isinstance(self.remarks, Unset):
             remarks = UNSET
         else:
             remarks = self.remarks
 
-        method_status_id: Union[None, Unset, int]
+        method_status_id: int | None | Unset
         if isinstance(self.method_status_id, Unset):
             method_status_id = UNSET
         elif isinstance(self.method_status_id, MethodStatusEnum):
@@ -70,7 +73,7 @@ class MethodTOTUpdate:
         else:
             method_status_id = self.method_status_id
 
-        updated_at: Union[None, Unset, str]
+        updated_at: None | str | Unset
         if isinstance(self.updated_at, Unset):
             updated_at = UNSET
         elif isinstance(self.updated_at, datetime.datetime):
@@ -78,19 +81,19 @@ class MethodTOTUpdate:
         else:
             updated_at = self.updated_at
 
-        updated_by: Union[None, Unset, str]
+        updated_by: None | str | Unset
         if isinstance(self.updated_by, Unset):
             updated_by = UNSET
         else:
             updated_by = self.updated_by
 
-        conducted_by: Union[None, Unset, str]
+        conducted_by: None | str | Unset
         if isinstance(self.conducted_by, Unset):
             conducted_by = UNSET
         else:
             conducted_by = self.conducted_by
 
-        conducted_at: Union[None, Unset, str]
+        conducted_at: None | str | Unset
         if isinstance(self.conducted_at, Unset):
             conducted_at = UNSET
         elif isinstance(self.conducted_at, datetime.datetime):
@@ -100,7 +103,7 @@ class MethodTOTUpdate:
 
         method_type_id = self.method_type_id
 
-        predrilling_depth: Union[None, Unset, float, str]
+        predrilling_depth: float | None | str | Unset
         if isinstance(self.predrilling_depth, Unset):
             predrilling_depth = UNSET
         else:
@@ -133,10 +136,10 @@ class MethodTOTUpdate:
         return field_dict
 
     @classmethod
-    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
-        d = src_dict.copy()
+    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
+        d = dict(src_dict)
 
-        def _parse_method_id(data: object) -> Union[None, UUID, Unset]:
+        def _parse_method_id(data: object) -> None | Unset | UUID:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -149,29 +152,29 @@ class MethodTOTUpdate:
                 return method_id_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, UUID, Unset], data)
+            return cast(None | Unset | UUID, data)
 
         method_id = _parse_method_id(d.pop("method_id", UNSET))
 
-        def _parse_name(data: object) -> Union[None, Unset, str]:
+        def _parse_name(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         name = _parse_name(d.pop("name", UNSET))
 
-        def _parse_remarks(data: object) -> Union[None, Unset, str]:
+        def _parse_remarks(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         remarks = _parse_remarks(d.pop("remarks", UNSET))
 
-        def _parse_method_status_id(data: object) -> Union[MethodStatusEnum, None, Unset]:
+        def _parse_method_status_id(data: object) -> MethodStatusEnum | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -184,11 +187,11 @@ class MethodTOTUpdate:
                 return method_status_id_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[MethodStatusEnum, None, Unset], data)
+            return cast(MethodStatusEnum | None | Unset, data)
 
         method_status_id = _parse_method_status_id(d.pop("method_status_id", UNSET))
 
-        def _parse_updated_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_updated_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -201,29 +204,29 @@ class MethodTOTUpdate:
                 return updated_at_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         updated_at = _parse_updated_at(d.pop("updated_at", UNSET))
 
-        def _parse_updated_by(data: object) -> Union[None, Unset, str]:
+        def _parse_updated_by(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         updated_by = _parse_updated_by(d.pop("updated_by", UNSET))
 
-        def _parse_conducted_by(data: object) -> Union[None, Unset, str]:
+        def _parse_conducted_by(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         conducted_by = _parse_conducted_by(d.pop("conducted_by", UNSET))
 
-        def _parse_conducted_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_conducted_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -236,20 +239,20 @@ class MethodTOTUpdate:
                 return conducted_at_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         conducted_at = _parse_conducted_at(d.pop("conducted_at", UNSET))
 
-        method_type_id = cast(Union[Literal[2], Unset], d.pop("method_type_id", UNSET))
+        method_type_id = cast(Literal[2] | Unset, d.pop("method_type_id", UNSET))
         if method_type_id != 2 and not isinstance(method_type_id, Unset):
             raise ValueError(f"method_type_id must match const 2, got '{method_type_id}'")
 
-        def _parse_predrilling_depth(data: object) -> Union[None, Unset, float, str]:
+        def _parse_predrilling_depth(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         predrilling_depth = _parse_predrilling_depth(d.pop("predrilling_depth", UNSET))
 
