@@ -1,4 +1,7 @@
-from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
+from __future__ import annotations
+
+from collections.abc import Mapping
+from typing import TYPE_CHECKING, Any, TypeVar, cast
 from uuid import UUID
 
 from attrs import define as _attrs_define
@@ -23,19 +26,19 @@ class PiezometerModel:
         name (str):
         default_pore_pressure_unit (str):
         vendor (PiezometerVendor):
-        piezometer_type (Union[None, Unset, str]):
-        default_transformation_type (Union[None, TransformationType, Unset]):
-        sort_order (Union[None, Unset, int]):
+        piezometer_type (None | str | Unset):
+        default_transformation_type (None | TransformationType | Unset):
+        sort_order (int | None | Unset):
     """
 
     model_id: UUID
     vendor_id: UUID
     name: str
     default_pore_pressure_unit: str
-    vendor: "PiezometerVendor"
-    piezometer_type: Union[None, Unset, str] = UNSET
-    default_transformation_type: Union[None, TransformationType, Unset] = UNSET
-    sort_order: Union[None, Unset, int] = UNSET
+    vendor: PiezometerVendor
+    piezometer_type: None | str | Unset = UNSET
+    default_transformation_type: None | TransformationType | Unset = UNSET
+    sort_order: int | None | Unset = UNSET
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
@@ -49,13 +52,13 @@ class PiezometerModel:
 
         vendor = self.vendor.to_dict()
 
-        piezometer_type: Union[None, Unset, str]
+        piezometer_type: None | str | Unset
         if isinstance(self.piezometer_type, Unset):
             piezometer_type = UNSET
         else:
             piezometer_type = self.piezometer_type
 
-        default_transformation_type: Union[None, Unset, str]
+        default_transformation_type: None | str | Unset
         if isinstance(self.default_transformation_type, Unset):
             default_transformation_type = UNSET
         elif isinstance(self.default_transformation_type, TransformationType):
@@ -63,7 +66,7 @@ class PiezometerModel:
         else:
             default_transformation_type = self.default_transformation_type
 
-        sort_order: Union[None, Unset, int]
+        sort_order: int | None | Unset
         if isinstance(self.sort_order, Unset):
             sort_order = UNSET
         else:
@@ -90,10 +93,10 @@ class PiezometerModel:
         return field_dict
 
     @classmethod
-    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
+    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
         from ..models.piezometer_vendor import PiezometerVendor
 
-        d = src_dict.copy()
+        d = dict(src_dict)
         model_id = UUID(d.pop("model_id"))
 
         vendor_id = UUID(d.pop("vendor_id"))
@@ -104,16 +107,16 @@ class PiezometerModel:
 
         vendor = PiezometerVendor.from_dict(d.pop("vendor"))
 
-        def _parse_piezometer_type(data: object) -> Union[None, Unset, str]:
+        def _parse_piezometer_type(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         piezometer_type = _parse_piezometer_type(d.pop("piezometer_type", UNSET))
 
-        def _parse_default_transformation_type(data: object) -> Union[None, TransformationType, Unset]:
+        def _parse_default_transformation_type(data: object) -> None | TransformationType | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -126,16 +129,16 @@ class PiezometerModel:
                 return default_transformation_type_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, TransformationType, Unset], data)
+            return cast(None | TransformationType | Unset, data)
 
         default_transformation_type = _parse_default_transformation_type(d.pop("default_transformation_type", UNSET))
 
-        def _parse_sort_order(data: object) -> Union[None, Unset, int]:
+        def _parse_sort_order(data: object) -> int | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, int], data)
+            return cast(int | None | Unset, data)
 
         sort_order = _parse_sort_order(d.pop("sort_order", UNSET))
 
