@@ -1,5 +1,7 @@
+from __future__ import annotations
+
 from collections.abc import Mapping
-from typing import Any, TypeVar, Union, cast
+from typing import Any, TypeVar, cast
 from uuid import UUID
 
 from attrs import define as _attrs_define
@@ -18,19 +20,19 @@ class PiezometerModelCreate:
         vendor_id (UUID):
         name (str):
         default_pore_pressure_unit (str):
-        model_id (Union[None, UUID, Unset]):
-        piezometer_type (Union[None, Unset, str]):
-        default_transformation_type (Union[None, TransformationType, Unset]):
-        sort_order (Union[None, Unset, int]):
+        model_id (None | Unset | UUID):
+        piezometer_type (None | str | Unset):
+        default_transformation_type (None | TransformationType | Unset):
+        sort_order (int | None | Unset):
     """
 
     vendor_id: UUID
     name: str
     default_pore_pressure_unit: str
-    model_id: Union[None, UUID, Unset] = UNSET
-    piezometer_type: Union[None, Unset, str] = UNSET
-    default_transformation_type: Union[None, TransformationType, Unset] = UNSET
-    sort_order: Union[None, Unset, int] = UNSET
+    model_id: None | Unset | UUID = UNSET
+    piezometer_type: None | str | Unset = UNSET
+    default_transformation_type: None | TransformationType | Unset = UNSET
+    sort_order: int | None | Unset = UNSET
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
@@ -40,7 +42,7 @@ class PiezometerModelCreate:
 
         default_pore_pressure_unit = self.default_pore_pressure_unit
 
-        model_id: Union[None, Unset, str]
+        model_id: None | str | Unset
         if isinstance(self.model_id, Unset):
             model_id = UNSET
         elif isinstance(self.model_id, UUID):
@@ -48,13 +50,13 @@ class PiezometerModelCreate:
         else:
             model_id = self.model_id
 
-        piezometer_type: Union[None, Unset, str]
+        piezometer_type: None | str | Unset
         if isinstance(self.piezometer_type, Unset):
             piezometer_type = UNSET
         else:
             piezometer_type = self.piezometer_type
 
-        default_transformation_type: Union[None, Unset, str]
+        default_transformation_type: None | str | Unset
         if isinstance(self.default_transformation_type, Unset):
             default_transformation_type = UNSET
         elif isinstance(self.default_transformation_type, TransformationType):
@@ -62,7 +64,7 @@ class PiezometerModelCreate:
         else:
             default_transformation_type = self.default_transformation_type
 
-        sort_order: Union[None, Unset, int]
+        sort_order: int | None | Unset
         if isinstance(self.sort_order, Unset):
             sort_order = UNSET
         else:
@@ -97,7 +99,7 @@ class PiezometerModelCreate:
 
         default_pore_pressure_unit = d.pop("default_pore_pressure_unit")
 
-        def _parse_model_id(data: object) -> Union[None, UUID, Unset]:
+        def _parse_model_id(data: object) -> None | Unset | UUID:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -110,20 +112,20 @@ class PiezometerModelCreate:
                 return model_id_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, UUID, Unset], data)
+            return cast(None | Unset | UUID, data)
 
         model_id = _parse_model_id(d.pop("model_id", UNSET))
 
-        def _parse_piezometer_type(data: object) -> Union[None, Unset, str]:
+        def _parse_piezometer_type(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         piezometer_type = _parse_piezometer_type(d.pop("piezometer_type", UNSET))
 
-        def _parse_default_transformation_type(data: object) -> Union[None, TransformationType, Unset]:
+        def _parse_default_transformation_type(data: object) -> None | TransformationType | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -136,16 +138,16 @@ class PiezometerModelCreate:
                 return default_transformation_type_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, TransformationType, Unset], data)
+            return cast(None | TransformationType | Unset, data)
 
         default_transformation_type = _parse_default_transformation_type(d.pop("default_transformation_type", UNSET))
 
-        def _parse_sort_order(data: object) -> Union[None, Unset, int]:
+        def _parse_sort_order(data: object) -> int | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, int], data)
+            return cast(int | None | Unset, data)
 
         sort_order = _parse_sort_order(d.pop("sort_order", UNSET))
 
