@@ -1,6 +1,8 @@
+from __future__ import annotations
+
 import datetime
 from collections.abc import Mapping
-from typing import Any, TypeVar, Union, cast
+from typing import Any, TypeVar, cast
 from uuid import UUID
 
 from attrs import define as _attrs_define
@@ -22,28 +24,28 @@ class ProjectCreate:
         organization_id (UUID):
         name (str):
         srid (int):
-        height_reference (Union[HeightReference, None]):
-        project_id (Union[None, UUID, Unset]):
-        created_at (Union[None, Unset, datetime.datetime]):
-        updated_at (Union[None, Unset, datetime.datetime]):
-        external_id_source (Union[None, Unset, str]):
-        standard_id (Union[None, StandardType, Unset]):  Default: StandardType.NGF.
-        description (Union[None, Unset, str]):
-        tags (Union[Unset, list[str]]):
+        height_reference (HeightReference | None):
+        project_id (None | Unset | UUID):
+        created_at (datetime.datetime | None | Unset):
+        updated_at (datetime.datetime | None | Unset):
+        external_id_source (None | str | Unset):
+        standard_id (None | StandardType | Unset):  Default: StandardType.NGF.
+        description (None | str | Unset):
+        tags (list[str] | Unset):
     """
 
     external_id: str
     organization_id: UUID
     name: str
     srid: int
-    height_reference: Union[HeightReference, None]
-    project_id: Union[None, UUID, Unset] = UNSET
-    created_at: Union[None, Unset, datetime.datetime] = UNSET
-    updated_at: Union[None, Unset, datetime.datetime] = UNSET
-    external_id_source: Union[None, Unset, str] = UNSET
-    standard_id: Union[None, StandardType, Unset] = StandardType.NGF
-    description: Union[None, Unset, str] = UNSET
-    tags: Union[Unset, list[str]] = UNSET
+    height_reference: HeightReference | None
+    project_id: None | Unset | UUID = UNSET
+    created_at: datetime.datetime | None | Unset = UNSET
+    updated_at: datetime.datetime | None | Unset = UNSET
+    external_id_source: None | str | Unset = UNSET
+    standard_id: None | StandardType | Unset = StandardType.NGF
+    description: None | str | Unset = UNSET
+    tags: list[str] | Unset = UNSET
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
@@ -55,13 +57,13 @@ class ProjectCreate:
 
         srid = self.srid
 
-        height_reference: Union[None, str]
+        height_reference: None | str
         if isinstance(self.height_reference, HeightReference):
             height_reference = self.height_reference.value
         else:
             height_reference = self.height_reference
 
-        project_id: Union[None, Unset, str]
+        project_id: None | str | Unset
         if isinstance(self.project_id, Unset):
             project_id = UNSET
         elif isinstance(self.project_id, UUID):
@@ -69,7 +71,7 @@ class ProjectCreate:
         else:
             project_id = self.project_id
 
-        created_at: Union[None, Unset, str]
+        created_at: None | str | Unset
         if isinstance(self.created_at, Unset):
             created_at = UNSET
         elif isinstance(self.created_at, datetime.datetime):
@@ -77,7 +79,7 @@ class ProjectCreate:
         else:
             created_at = self.created_at
 
-        updated_at: Union[None, Unset, str]
+        updated_at: None | str | Unset
         if isinstance(self.updated_at, Unset):
             updated_at = UNSET
         elif isinstance(self.updated_at, datetime.datetime):
@@ -85,13 +87,13 @@ class ProjectCreate:
         else:
             updated_at = self.updated_at
 
-        external_id_source: Union[None, Unset, str]
+        external_id_source: None | str | Unset
         if isinstance(self.external_id_source, Unset):
             external_id_source = UNSET
         else:
             external_id_source = self.external_id_source
 
-        standard_id: Union[None, Unset, str]
+        standard_id: None | str | Unset
         if isinstance(self.standard_id, Unset):
             standard_id = UNSET
         elif isinstance(self.standard_id, StandardType):
@@ -99,13 +101,13 @@ class ProjectCreate:
         else:
             standard_id = self.standard_id
 
-        description: Union[None, Unset, str]
+        description: None | str | Unset
         if isinstance(self.description, Unset):
             description = UNSET
         else:
             description = self.description
 
-        tags: Union[Unset, list[str]] = UNSET
+        tags: list[str] | Unset = UNSET
         if not isinstance(self.tags, Unset):
             tags = self.tags
 
@@ -148,7 +150,7 @@ class ProjectCreate:
 
         srid = d.pop("srid")
 
-        def _parse_height_reference(data: object) -> Union[HeightReference, None]:
+        def _parse_height_reference(data: object) -> HeightReference | None:
             if data is None:
                 return data
             try:
@@ -159,11 +161,11 @@ class ProjectCreate:
                 return height_reference_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[HeightReference, None], data)
+            return cast(HeightReference | None, data)
 
         height_reference = _parse_height_reference(d.pop("height_reference"))
 
-        def _parse_project_id(data: object) -> Union[None, UUID, Unset]:
+        def _parse_project_id(data: object) -> None | Unset | UUID:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -176,11 +178,11 @@ class ProjectCreate:
                 return project_id_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, UUID, Unset], data)
+            return cast(None | Unset | UUID, data)
 
         project_id = _parse_project_id(d.pop("project_id", UNSET))
 
-        def _parse_created_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_created_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -193,11 +195,11 @@ class ProjectCreate:
                 return created_at_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         created_at = _parse_created_at(d.pop("created_at", UNSET))
 
-        def _parse_updated_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_updated_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -210,20 +212,20 @@ class ProjectCreate:
                 return updated_at_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         updated_at = _parse_updated_at(d.pop("updated_at", UNSET))
 
-        def _parse_external_id_source(data: object) -> Union[None, Unset, str]:
+        def _parse_external_id_source(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         external_id_source = _parse_external_id_source(d.pop("external_id_source", UNSET))
 
-        def _parse_standard_id(data: object) -> Union[None, StandardType, Unset]:
+        def _parse_standard_id(data: object) -> None | StandardType | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -236,16 +238,16 @@ class ProjectCreate:
                 return standard_id_type_0
             except:  # noqa: E722
                 pass
-            return cast(Union[None, StandardType, Unset], data)
+            return cast(None | StandardType | Unset, data)
 
         standard_id = _parse_standard_id(d.pop("standard_id", UNSET))
 
-        def _parse_description(data: object) -> Union[None, Unset, str]:
+        def _parse_description(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         description = _parse_description(d.pop("description", UNSET))
 
