@@ -1,5 +1,7 @@
+from __future__ import annotations
+
 from collections.abc import Mapping
-from typing import Any, TypeVar, Union, cast
+from typing import Any, TypeVar, cast
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
@@ -18,15 +20,15 @@ class WebMapServiceCreate:
         name (str):
         url (str):
         service_type (WebMapServiceType):
-        available_standard_ids (Union[Unset, list[StandardType]]):
-        description (Union[None, Unset, str]):
+        available_standard_ids (list[StandardType] | Unset):
+        description (None | str | Unset):
     """
 
     name: str
     url: str
     service_type: WebMapServiceType
-    available_standard_ids: Union[Unset, list[StandardType]] = UNSET
-    description: Union[None, Unset, str] = UNSET
+    available_standard_ids: list[StandardType] | Unset = UNSET
+    description: None | str | Unset = UNSET
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
@@ -36,14 +38,14 @@ class WebMapServiceCreate:
 
         service_type = self.service_type.value
 
-        available_standard_ids: Union[Unset, list[str]] = UNSET
+        available_standard_ids: list[str] | Unset = UNSET
         if not isinstance(self.available_standard_ids, Unset):
             available_standard_ids = []
             for available_standard_ids_item_data in self.available_standard_ids:
                 available_standard_ids_item = available_standard_ids_item_data.value
                 available_standard_ids.append(available_standard_ids_item)
 
-        description: Union[None, Unset, str]
+        description: None | str | Unset
         if isinstance(self.description, Unset):
             description = UNSET
         else:
@@ -81,12 +83,12 @@ class WebMapServiceCreate:
 
             available_standard_ids.append(available_standard_ids_item)
 
-        def _parse_description(data: object) -> Union[None, Unset, str]:
+        def _parse_description(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         description = _parse_description(d.pop("description", UNSET))
 
